set scheme s2color

******************************************************
***FIGURE 3a,b: TREATMENT EFFECT BY CONTROL TAKE-UP***
******************************************************
{
	**Academic Journals
	clear all
	use "./cleaned_data/AcademicJournals.dta"

	*Coordinates for labeled outliers
	qui sum controltakeup if trialnumber==103 & trialsample==1 & armnumber==1
	local A_c = r(mean)
	qui sum treatmenteffectupperCI if trialnumber==103 & trialsample==1 & armnumber==1
	local A_te = r(mean)+1
	local A_x = `A_c'-1
	local A_xtxt = `A_c'+1
	local A_y = `A_te'+8
	local A_ytxt = `A_y'+1

	qui sum controltakeup if trialnumber==104 & trialsample==2 & armnumber==1
	local B_c = r(mean)
	qui sum treatmenteffectupperCI if trialnumber==104 & trialsample==2 & armnumber==1
	local B_te = r(mean)+1
	local B_x = `B_c'
	local B_xtxt = `B_x'
	local B_y = `B_te'+3
	local B_ytxt = `B_y'+1

	qui sum controltakeup if trialnumber==58 & trialsample==1 & armnumber==1
	local C_c = r(mean)+2
	qui sum treatmenteffect if trialnumber==58 & trialsample==1 & armnumber==1
	local C_te = r(mean)
	local C_x = `C_c'+3
	local C_xtxt = `C_x'+1
	local C_y = `C_te'
	local C_ytxt = `C_y'

	qui sum controltakeup
	local c = r(mean)
	qui sum treatmenteffect
	local m = r(mean)

	qui count if controltakeup!=. & treatmenteffectupperCI!=. & treatmenteffect!=.
	local Ntotal = r(N)
	qui sum treatmenteffect if controltakeup!=. & treatmenteffectupperCI!=. & treatmenteffect!=. & treatmenteffect<=40
	local m = r(mean)
	local N = r(N)
	local Noutliers = `Ntotal'-`N'
	qui distinct trialnumber if controltakeup!=. & treatmenteffectupperCI!=. & treatmenteffect!=. & treatmenteffect<=40
	local tr = r(ndistinct)
	qui sum controltakeup if controltakeup!=. & treatmenteffectupperCI!=. & treatmenteffect!=. & treatmenteffect<=40
	local c = r(mean)
	
	twoway rcap treatmenteffectlowerCI treatmenteffectupperCI controltakeup if controltakeup!=. & treatmenteffectupperCI!=. & treatmenteffect!=. & treatmenteffect<=40, lstyle(ci) || ///
		   scatter treatmenteffect controltakeup if controltakeup!=. & treatmenteffectupperCI!=. & treatmenteffect!=. & treatmenteffect<=40, mcolor(maroon%30) || ///
		   qfit treatmenteffect controltakeup if controltakeup!=. & treatmenteffectupperCI!=. & treatmenteffect!=. & treatmenteffect<=40 || ///
		   pcarrowi 	`A_y' `A_x' `A_te' `A_c' ///
				`B_y' `B_x' `B_te' `B_c' ///
				`C_y' `C_x' `C_te' `C_c' ///
		   , ///
		   mcolor(navy) lcolor(navy) mlabcolor(navy) mlabsize(small) legend(off) ///
		   text(`A_ytxt' `A_xtxt' "Active decision in 401k enrollment" "(Carroll et al., 2009)", place(nw) color(navy) size(small) just(right)) ///
		   text(`B_ytxt' `B_xtxt' "H&R Block FAFSA experiment" "(Bettinger et al., 2012)", place(n) color(navy) size(small) just(center)) ///
		   text(`C_ytxt' `C_xtxt' "Changing menu order" "in buffet line for healthier" "food consumption" "(Wansink & Hanks, 2013)", place(e) color(navy) size(small) just(left)) ///
		   legend(off) ///
		   xscale(range(0 100)) yscale(range(-20 40)) ///
		   yline(0, lcolor(gray)) ///	   
		   xlabel(0(20)100) xmtick(0(20)100) ylabel(-20(10)40) ymtick(-20(10)40) ///
		   graphregion(color(white)) bgcolor(white) ///
		   ytitle("Treatment effect (pp.)") xtitle("Control take-up (%)") ///
		note("Sample: `N' nudges (`tr' trials)" "`Noutliers' nudges with treatment effects >40 pp. are not shown.")
	graph export "./output/figures_final/HMB_xcontrol_yTE.pdf", replace
	
	**Nudge Units
	clear all
	use "./cleaned_data/NudgeUnits.dta"

	*Coordinates for labeled outliers
	qui sum controltakeup if trialnumber==2016059 & armnumber==1
	local A_c = r(mean)+2
	qui sum treatmenteffect if trialnumber==2016059 & armnumber==1
	local A_te1 = r(mean)
	qui sum treatmenteffect if trialnumber==2016059 & armnumber==2
	local A_te2 = r(mean)
	local A_x = `A_c'+5
	local A_y = (`A_te1'+`A_te2')/2

	qui sum controltakeup if trialnumber==2017171 & armnumber==2
	local B_c = r(mean)-2
	qui sum treatmenteffect if trialnumber==2017171 & armnumber==2
	local B_te1 = r(mean)
	qui sum treatmenteffect if trialnumber==2017171 & armnumber==3
	local B_te2 = r(mean)
	local B_x = `B_c'-5
	local B_y = `B_te2'
	local B_ytxt = `B_y'+1

	qui sum controltakeup
	local c = r(mean)
	qui sum treatmenteffect
	local m = r(mean)

	qui sum controltakeup if trialnumber==2015105 & armnumber==1
	local C_c = r(mean)+2
	qui sum treatmenteffect if trialnumber==2015105 & armnumber==1
	local C_te = r(mean)
	local C_x = `C_c'+5
	local C_y = `C_te'

	qui sum controltakeup if trialnumber==2018132 & armnumber==1
	local D_c = r(mean)+2
	qui sum treatmenteffect if trialnumber==2018132 & armnumber==1
	local D_te = r(mean)
	local D_x = `D_c'+5
	local D_y = `D_te'

	count if controltakeup==.
	local Nmissing = r(N)
	count if controltakeup!=.
	local N = r(N)

	qui distinct trialnumber if controltakeup!=.
	local tr = r(ndistinct)
	qui distinct trialnumber if controltakeup==.
	local trmissing = r(ndistinct)
	twoway rcap treatmenteffectlowerCI treatmenteffectupperCI controltakeup if controltakeup!=. & treatmenteffectupperCI!=. & treatmenteffect!=., lstyle(ci) || ///
		   scatter treatmenteffect controltakeup if controltakeup!=. & treatmenteffectupperCI!=. & treatmenteffect!=., mcolor(maroon%30) || ///
		   qfit treatmenteffect controltakeup if controltakeup!=. & treatmenteffectupperCI!=. & treatmenteffect!=. || ///
		   pcarrowi 	`A_y' `A_x' `A_te1' `A_c' `A_y' `A_x' `A_te2' `A_c' (3) "Letters enforcing delinquent sewer bill payment" ///
				`B_y' `B_x' `B_te1' `B_c' `B_y' `B_x' `B_te2' `B_c' ///
				`C_y' `C_x' `C_te' `C_c' (3) "Courtesy reminders for sewer bill payment" ///
				`D_y' `D_x' `D_te' `D_c' (3) "Redesigned webpage encouraging applications to city board" ///
		   , ///
		   mcolor(navy) lcolor(navy) mlabcolor(navy) mlabsize(small) legend(off) ///
		   text(`B_ytxt' `B_c' "Emails prompting" "online AutoPay" "registration for" "city bills", place(nw) color(navy) size(small) just(center)) ///
		   xscale(range(0 100)) ///
		   yscale(range(-20 40)) ///
		   yline(0, lcolor(gray)) ///	   
		   xlabel(0(20)100) xmtick(0(20)100) ylabel(-20(10)40) ymtick(-20(10)40) ///
		   graphregion(color(white)) bgcolor(white) ///
		   ytitle("Treatment effect (pp.)") xtitle("Control take-up (%)") ///
		   note("Sample: `N' nudges (`tr' trials)" "`Nmissing' nudges (`trmissing' trials) with missing control take-up data are not shown.")
	graph export "./output/figures_final/OESBIT_xcontrol_yTE.pdf", replace
}

******************************************
***FIGURE 4a, A4a: MDE, TREATMENT N CDF***
******************************************
{
	clear all
	use "./cleaned_data/NudgeUnits.dta"

	cumul mde if mde!=., gen(cumulOB)
	qui sum mde, d
	local meanOBg = `r(mean)'+0.1
	local medianOBg = `r(p50)'+0.1
	local meanOB = string(`r(mean)',"%4.2f")
	local medianOB = string(`r(p50)',"%4.2f")
	local NOB = `r(N)'
	qui distinct trialnumber if mde!=.
	local trOB = r(ndistinct)

	gen OB = 1
	tempfile OB
	drop if mde==.
	keep OB mde cumulOB
	save `OB'

	use "./cleaned_data/AcademicJournals.dta", clear
	cumul mde if mde!=., gen(cumulHMB)
	qui sum mde, d
	local meanHMBg = `r(mean)'+0.1
	local medianHMBg = `r(p50)'+0.1
	local meanHMB = string(`r(mean)',"%4.2f")
	local medianHMB = string(`r(p50)',"%4.2f")
	local NHMB = `r(N)'
	qui distinct trialnumber if mde!=.
	local trHMB = r(ndistinct)

	gen OB = 0
	append using `OB'

	label var cumulOB "Nudge Units"
	label var cumulHMB "Academic Journals"

	replace cumulHMB=(15-12.618)/(17.065-12.618)*(0.838-0.824)+0.824 if trialnumber==104 & armnumber==2 & trialsample==1 // for x-axis to 15pp
	replace mde=15 if trialnumber==104 & armnumber==2 & trialsample==1 // for x-axis to 15pp

	twoway (line cumulOB mde if mde<=15 & OB==1, sort(cumulOB) lcolor(blue)) ///
			(line cumulHMB mde if mde<=15 & OB==0, sort(cumulHMB) lcolor(red) lwidth(thick)), ///
			graphregion(color(white)) bgcolor(white) ///
			xlabel(0(1)15) xticks(0(1)15) ///
			xtitle("Minimum detectable effect (pp.) with power 0.8") ytitle("CDF") ///
			xline(`meanHMB', lcolor(red) lwidth(thick)) ///
			xline(`medianHMB', lpattern(dash) lcolor(red) lwidth(thick)) ///
			xline(`meanOB', lcolor(blue)) ///
			xline(`medianOB', lpattern(dash) lcolor(blue)) ///
			text(0 `meanHMBg' "{&larr}mean (`meanHMB')", place(e) color(red) size(small) box bcolor(white)) ///
			text(0.2 `medianHMBg' "{&larr}median (`medianHMB')", place(e) color(red) size(small) box bcolor(white)) ///
			text(0.6 `meanOBg' "{&larr}mean (`meanOB')", place(e) color(blue) size(small) box bcolor(white)) ///
			text(1 `medianOBg' "{&larr}median (`medianOB')", place(e) color(blue) size(small) box bcolor(white)) ///
			note("Nudge Units sample: `NOB' nudges, `trOB' trials" "Academic Journals sample: `NHMB' nudges, `trHMB' trials")
	graph export "./output/figures_final/MDE_bounded.png", replace width(1434) height(1041)

	clear all
	use "./cleaned_data/NudgeUnits.dta"

	gen logtreatmentN=log10(treatmentN)
	cumul logtreatmentN if logtreatmentN!=., gen(cumulOB)
	qui sum treatmentN, d
	local meanOBg = log10(`r(mean)')+0.02
	local medianOBg = log10(`r(p50)')+0.02
	local meanOBl = log10(`r(mean)')
	local medianOBl = log10(`r(p50)')
	local meanOB = string(`r(mean)',"%4.0f")
	local medianOB = string(`r(p50)',"%4.0f")
	local NOB = `r(N)'
	qui distinct trialnumber if logtreatmentN!=.
	local trOB = r(ndistinct)

	gen OB = 1
	tempfile OB
	drop if logtreatmentN==.
	keep OB logtreatmentN cumulOB
	save `OB'

	use "./cleaned_data/AcademicJournals.dta", clear

	gen logtreatmentN=log10(treatmentN)
	cumul logtreatmentN if logtreatmentN!=., gen(cumulHMB)
	qui sum treatmentN, d
	local meanHMBg = log10(`r(mean)')-0.02
	local medianHMBg = log10(`r(p50)')-0.02
	local meanHMBl = log10(`r(mean)')
	local medianHMBl = log10(`r(p50)')
	local meanHMB = string(`r(mean)',"%4.0f")
	local medianHMB = string(`r(p50)',"%4.0f")
	local NHMB = `r(N)'
	qui distinct trialnumber if logtreatmentN!=.
	local trHMB = r(ndistinct)

	gen OB = 0
	append using `OB'

	label var cumulOB "Nudge Units"
	label var cumulHMB "Academic Journals"

	twoway (line cumulOB logtreatmentN if OB==1, sort(cumulOB) lcolor(blue)) ///
			(line cumulHMB logtreatmentN if OB==0, sort(cumulHMB) lcolor(red) lwidth(thick)), ///
			graphregion(color(white)) bgcolor(white) ///
			xlabel(2 "100" 3 "1,000" 4 "10,000" 5 "100,000" 6 "1,000,000") ///
			xtitle("Treatment arm sample size (log scale)") ytitle("CDF") ///
			xline(`meanHMBl', lcolor(red) lwidth(thick)) ///
			xline(`medianHMBl', lpattern(dash) lcolor(red) lwidth(thick)) ///
			xline(`meanOBl', lcolor(blue)) ///
			xline(`medianOBl', lpattern(dash) lcolor(blue)) ///
			text(0.9 `meanHMBg' "mean (`meanHMB'){&rarr}", place(w) color(red) size(small) box bcolor(white)) ///
			text(1 `medianHMBg' "median (`medianHMB'){&rarr}", place(w) color(red) size(small) box bcolor(white)) ///
			text(0.1 `meanOBg' "{&larr}mean (`meanOB')", place(e) color(blue) size(small) box bcolor(white)) ///
			text(0.2 `medianOBg' "{&larr}median (`medianOB')", place(e) color(blue) size(small) box bcolor(white)) ///
			note("Nudge Units sample: `NOB' nudges, `trOB' trials" "Academic Journals sample: `NHMB' nudges, `trHMB' trials")
	graph export "./output/figures_final/logtreatmentN.png", replace width(1434) height(1041)
}

*****************************************
***FIGURE 4b, A10, A11, A12: FORECASTS***
*****************************************
{
	clear all
	use "./cleaned_data/Forecasts.dta"

	*Forecaster characteristics
	qui count if byresp==1 & avgte!=.
	local n = r(N)
	graph hbar if byresp==1, over(affil, sort(1) descending) ///
		graphregion(color(white)) bgcolor(white) ///
		ytitle("Percent of sample (n=`n')") ylabel(0(5)30) blabel(bar, format(%4.2f))
	graph export "./output/figures_final/forecasters_affil.pdf", replace

	gen a=1
	qui count if field!="" & byresp==1
	local n = r(N)
	graph hbar (percent) a if byresp==1, over(field, sort(order)) ///
		graphregion(color(white)) bgcolor(white) ///
		ytitle("Percent of sample (n=`n')") ylabel(0(5)30) blabel(bar, format(%4.2f))
	graph export "./output/figures_final/forecasters_field.pdf", replace
	drop a

	qui count if fieldexpgroup!="" & byresp==1
	local n = r(N)
	graph hbar if byresp==1, over(fieldexpgroup, sort(1) descending) ///
		graphregion(color(white) margin(2 10 2 2)) bgcolor(white) ///
		bargap(1) ///
		ytitle("Percent of sample (n=`n')") blabel(bar, format(%4.2f))
	graph export "./output/figures_final/forecasters_exp.pdf", replace
	
	*Forecasts
	cumul avgte if byresp==1 & affil=="Academic researcher", gen(cumula)
	qui sum avgte if byresp==1 & affil=="Academic researcher", d
	local Na = r(N)
	local meana = string(`r(mean)',"%4.2f")
	local meanag = `meana'+0.2
	local mediana = string(`r(p50)',"%4.2f")
	local medianag = `mediana'+0.1
	cumul hmb if byresp==1 & affil=="Academic researcher" & hmb!=-99, gen(cumulb)
	qui sum hmb if byresp==1 & affil=="Academic researcher" & hmb!=-99, d
	local Nb = r(N)
	local meanb = string(`r(mean)',"%4.2f")
	local meanbg = `meanb'+0.1
	local medianb = string(`r(p50)',"%4.2f")
	local medianbg = `medianb'+0.1
	cumul avgte if byresp==1 & expgroup==2, gen(cumulc)
	qui sum avgte if byresp==1 & expgroup==2, d
	local Nc = r(N)
	local meanc = string(`r(mean)',"%4.2f")
	local meancg = `meanc'+0.1
	local medianc = string(`r(p50)',"%4.2f")
	local mediancg = `medianc'+0.1
	label var cumula "Academics forecasting Nudge Unit trials (N=`Na')"
	label var cumulb "Academics forecasting Acad. Journal trials (N=`Nb')"
	label var cumulc "Nudge practitioners forecasting Nudge Unit trials (N=`Nc')"
	replace cumulc=(0.929+0.964)/2 if avgte==20 & byresp==1 & expgroup==2 // for x-axis up to 15pp
	replace avgte=15 if avgte==20 & byresp==1 & expgroup==2 // for x-axis up to 15pp
		
	twoway  (line cumula avgte if byresp==1 & affil=="Academic researcher" & avgte<=15, sort(cumula) lcolor(ebblue) lwidth(medthick)) ///
			(line cumulb hmb if byresp==1 & affil=="Academic researcher" & hmb!=-99 & hmb<=15, sort(cumulb) lcolor(red) lwidth(thin)) ///
			(line cumulc avgte if byresp==1 & expgroup==2 & avgte<=15, sort(cumulc) lcolor(blue) lwidth(thick)), ///
			graphregion(color(white)) bgcolor(white) ///
			xticks(0(1)15) xlabel(0(1)15) ///
			xtitle("Forecasted average treatment effect (pp.)") ytitle("CDF") ///
			xline(`medianb', lpattern(dash) lcolor(red) lwidth(thin)) ///
			xline(`medianc', lpattern(dash) lcolor(blue) lwidth(thick)) ///
			xline(`mediana', lpattern(dash) lcolor(ebblue) lwidth(medthick)) ///
			text(0.525 `medianag' "{&larr}median (`mediana' pp.)", place(e) color(ebblue) size(small) box bcolor(white)) ///
			text(0.1 `medianbg' "{&larr}median (`medianb' pp.)", place(e) color(red) size(small) box bcolor(white)) ///
			text(1 `mediancg' "{&larr}median (`medianc' pp.)", place(e) color(blue) size(small) box bcolor(white)) ///
			legend(order(3 "Nudge practitioners forecasting Nudge Unit trials (N=`Nc')" 1 "Academics forecasting Nudge Unit trials (N=`Na')" 2 "Academics forecasting Academic Journal trials (N=`Nb')") cols(1))
	graph export "./output/figures_final/forecasts_CDF.png", replace width(1434) height(1041)
	drop cumula cumulb cumulc
	
	*Heterogeneity in forecasts
	cumul avgte if byresp==1 & expgroup==0, gen(cumula)
	qui sum avgte if expgroup==0 & byresp==1, d
	local Na = r(N)
	local meana = string(`r(mean)',"%4.2f")
	local meanag = `meana'+0.1
	local mediana = string(`r(p50)',"%4.2f")
	local medianag = `mediana'+0.1
	cumul avgte if byresp==1 & expgroup==1, gen(cumulb)
	qui sum avgte if expgroup==1 & byresp==1, d
	local Nb = r(N)
	local meanb = string(`r(mean)',"%4.2f")
	local meanbg = `meanb'+0.1
	local medianb = string(`r(p50)',"%4.2f")
	local medianbg = `medianb'+0.1
	cumul avgte if byresp==1 & expgroup==2, gen(cumulc)
	qui sum avgte if expgroup==2 & byresp==1, d
	local Nc = r(N)
	local meanc = string(`r(mean)',"%4.2f")
	local meancg = `meanc'+0.1
	local medianc = string(`r(p50)',"%4.2f")
	local mediancg = `medianc'+0.1
	label var cumula "0 field experiments (N=`Na')"
	label var cumulb ">5 field experiments (N=`Nb')"
	label var cumulc "Nudge practitioners (N=`Nc')"

	twoway (line cumula avgte if byresp==1 & expgroup==0 & avgte<=20, sort(cumula) lcolor(midblue) lwidth(thin)) ///
			(line cumulb avgte if byresp==1 & expgroup==1 & avgte<=20, sort(cumulb) lcolor(edkblue) lwidth(medthick)) ///
			(line cumulc avgte if byresp==1 & expgroup==2 & avgte<=20, sort(cumulc) lcolor(ebblue) lwidth(thick)), ///
			graphregion(color(white)) bgcolor(white) ///
			xtitle("Forecasted average treatment effect for Nudge Units (pp.)") ytitle("CDF") ///
			xscale(range(-3 20)) xtick(0(5)20) ///
			xline(`mediana', lpattern(dash) lcolor(midblue) lwidth(thin)) ///
			xline(`medianb', lpattern(dash) lcolor(edkblue) lwidth(medthick)) ///
			xline(`medianc', lpattern(dash) lcolor(ebblue) lwidth(thick)) ///
			text(0.1 `medianag' "{&larr}median (`mediana' pp.)", place(e) color(midblue) size(small) box bcolor(white)) ///
			text(0.3 `medianbg' "{&larr}median (`medianb' pp.)", place(e) color(edkblue) size(small) box bcolor(white)) ///
			text(1 `mediancg' "{&larr}median (`medianc' pp.)", place(e) color(ebblue) size(small) box bcolor(white))
	graph export "./output/figures_final/forecasts_CDF_hetero.png", replace width(1434) height(1041)
	drop cumula cumulb cumulc

	cumul hmb if byresp==1 & expgroup==0 & hmb!=-99, gen(cumula)
	qui sum hmb if expgroup==0 & byresp==1 & hmb!=-99, d
	local Na = r(N)
	local meana = string(`r(mean)',"%4.2f")
	local meanag = `meana'+0.2
	local mediana = string(`r(p50)',"%4.2f")
	local medianag = `mediana'+0.2
	cumul hmb if byresp==1 & expgroup==1 & hmb!=-99, gen(cumulb)
	qui sum hmb if expgroup==1 & byresp==1 & hmb!=-99, d
	local Nb = r(N)
	local meanb = string(`r(mean)',"%4.2f")
	local meanbg = `meanb'+0.2
	local medianb = string(`r(p50)',"%4.2f")
	local medianbg = `medianb'+0.2
	cumul hmb if byresp==1 & expgroup==2 & hmb!=-99, gen(cumulc)
	qui sum hmb if expgroup==2 & byresp==1 & hmb!=-99, d
	local Nc = r(N)
	local meanc = string(`r(mean)',"%4.2f")
	local meancg = `meanc'+0.2
	local medianc = string(`r(p50)',"%4.2f")
	local mediancg = `medianc'+0.2
	label var cumula "0 field experiments (N=`Na')"
	label var cumulb ">5 field experiments (N=`Nb')"
	label var cumulc "Nudge practitioners (N=`Nc')"

	twoway (line cumula hmb if byresp==1 & expgroup==0 & hmb!=-99 & hmb<=25, sort(cumula) lcolor(midblue) lwidth(thin)) ///
			(line cumulb hmb if byresp==1 & expgroup==1 & hmb!=-99 & hmb<=25, sort(cumulb) lcolor(edkblue) lwidth(medthick)) ///
			(line cumulc hmb if byresp==1 & expgroup==2 & hmb!=-99 & hmb<=25, sort(cumulc) lcolor(ebblue) lwidth(thick)), ///
			graphregion(color(white)) bgcolor(white) ///
			xtitle("Forecasted average treatment effect for Academic Journals (pp.)") ytitle("CDF") ///
			xline(`mediana', lpattern(dash) lcolor(midblue) lwidth(thin)) ///
			xline(`medianb', lpattern(dash) lcolor(edkblue) lwidth(medthick)) ///
			xline(`medianc', lpattern(dash) lcolor(ebblue) lwidth(thick)) ///
			text(0.1 `medianag' "{&larr}median (`mediana' pp.)", place(e) color(midblue) size(small) box bcolor(white)) ///
			text(0.3 `medianbg' "{&larr}median (`medianb' pp.)", place(e) color(edkblue) size(small) box bcolor(white)) ///
			text(1 `mediancg' "{&larr}median (`medianc' pp.)", place(e) color(ebblue) size(small) box bcolor(white))
	graph export "./output/figures_final/forecasts_pub_CDF_hetero.png", replace width(1434) height(1041)
	drop cumula cumulb cumulc

	*Forecasts for specific examples
	qui tab te, gen(example)
	gen examplenum = .
	forvalues i=1/14 {
		replace examplenum = `i' if example`i'==1
	}
	
	preserve
		collapse (median) fte (mean) te (count) count=fte (sd) sd=fte, by(examplenum)
		label var fte "Median forecasted treatment effect (pp.)"
		label var te "True treatment effect (pp.)"

		qui reg fte te
		local cons = string(_b[_cons],"%4.3f")
		local consSE = string(_se[_cons],"%4.3f")
		local beta = string(_b[te],"%4.3f")
		local betaSE = string(_se[te],"%4.3f")
		local N = e(N)

		qui sum fte if te>=2.65 & te<=2.75
		local A_fte = r(mean)-0.3
		local A_te = 2.7+0.1
		local A_x = 2.7+0.5
		local A_y = `A_fte'-0.75

		qui sum fte if te>8
		local B_fte = r(mean)-0.3
		local B_te = 8.18-0.1
		local B_x = 8.18-0.5
		local B_y = `B_fte'-1

		twoway scatter fte te, mlabel(count) || lfit fte te, lcolor(navy) || line te te, lpattern(dash) lcolor(gray) || ///
			pcarrowi 	`A_y' `A_x' `A_fte' `A_te' (3) "Active decision for health appointment" ///
					`B_y' `B_x' `B_fte' `B_te' (9) "Simplified ''Track Your Ballot'' webpage", ///
			mcolor(midblue) lcolor(midblue) mlabcolor(midblue) mlabsize(small) ///
			graphregion(color(white)) bgcolor(white) ///
			legend(off) xtitle("True treatment effect (pp.)") ytitle("Median forecasted T.E. (pp.)") ///
			subtitle("y = `cons' + `beta'x" "     (`consSE')  (`betaSE')", justification(left)) ///
			note("`N' examples. Numeric labels are the number of forecasts for each example." "45 degree dashed line shown.", justification(left))
		graph export "./output/figures_final/forecasts_examples_scatter.pdf", replace
	restore

	preserve
		replace expgroup=1 if expgroup==2
		collapse (median) fte (mean) te (count) count=fte (sd) sd=fte, by(examplenum expgroup)
		label var fte "Median forecasted T.E. (pp.)"
		label var te "True treatment effect (pp.)"

		forvalues e=0/1 {
			qui reg fte te if exp==`e'
			local cons`e' = string(_b[_cons],"%4.3f")
			local consSE`e' = string(_se[_cons],"%4.3f")
			local beta`e' = string(_b[te],"%4.3f")
			local betaSE`e' = string(_se[te],"%4.3f")
			local N = e(N)
			local start`e' = `cons`e''+`beta`e''*4+(`e'*(-0.2)+0.1)
			local end`e' = `cons`e''+`beta`e''*4+(`e'*(-2)+1)
		}

		twoway 	line te te, lpattern(dash) lcolor(gray) || ///
			lfit fte te if expgroup==0, lcolor(navy) || ///
			lfit fte te if expgroup==1, lcolor(maroon) lwidth(thick) || ///
			scatter fte te if expgroup==0, mlabel(count) mcolor(navy%50) mlabcol(navy) msize(small) mlabp(3) || ///
			scatter fte te if expgroup==1, mlabel(count) mcolor(maroon%50) mlabcol(maroon) msymbol(S) msize(small) mlabp(3) || ///
			pcarrowi `end0' 4 `start0' 4 (12) "Slope: `beta0' (`betaSE0')" ///
				 `end1' 4 `start1' 4 (6) "Slope: `beta1' (`betaSE1')" ///
			, ///
			mcolor(gray) lcolor(gray) mlabcolor(gray) mlabsize(small) ///
			graphregion(color(white)) bgcolor(white) ///
			legend(order(4 "No field experience" 5 "Experienced/practitioners") width(90)) ///
			xtitle("True treatment effect (pp.)") ytitle("Median forecasted T.E. (pp.)") ///
			yscale(range(0(2)10)) yticks(0(2)10) ylabels(0(2)10) ///
			note( ///
			"Experienced respondents: >5 field experiments experience/nudge practitioners." ///
			"`N' examples. Numeric labels are the number of forecasts for each example." "45 degree dashed line shown.", justification(left))
		graph export "./output/figures_final/forecasts_examples_scatter_byexp.pdf", replace
	restore
}

****************************************************************
***FIGURES 5a, 6a, A5a, A5b, A9a: PUBLICATION BIAS REGRESSION***
****************************************************************
{
	**Academic Journals
	use "./cleaned_data/AcademicJournals.dta", clear

	qui reg treatmenteffect mde, cluster(trialnumber)
	local cons = string(_b[_cons],"%4.3f")
	local consmde = string(_se[_cons],"%4.3f")
	local beta = string(_b[mde],"%4.3f")
	local betamde = string(_se[mde],"%4.3f")
	local N = e(N)
	local cl = e(N_clust)
	twoway (scatter treatmenteffect mde, mcolor(navy%30)) (lfit treatmenteffect mde), ///
		graphregion(color(white)) bgcolor(white) ///
		xscale(range(0 25)) yscale(range(-20 50)) ///
		xmtick(0(5)25) ymtick(-20(10)50) ///
		xlabel(0(5)25) ylabel(-20(10)50) ///
		legend(off) xtitle("Minimum detectable effect (pp.) with power 0.8") ytitle("Treatment effect (pp.)") ///
		subtitle("y = `cons' + `beta'x" "     (`consmde')  (`betamde')", justification(left)) ///
		note("Entire sample: `N' treatments, `cl' trials" "Standard errors clustered by trial in parentheses", justification(left))
	graph export "./output/figures_final/HMB_pubbias_mde.pdf", replace
	
	qui reg treatmenteffect SE, cluster(trialnumber)
	local cons = string(_b[_cons],"%4.3f")
	local consSE = string(_se[_cons],"%4.3f")
	local beta = string(_b[SE],"%4.3f")
	local betaSE = string(_se[SE],"%4.3f")
	local N = e(N)
	local cl = e(N_clust)
	twoway (scatter treatmenteffect SE, mcolor(navy%30)) (lfit treatmenteffect SE), ///
		graphregion(color(white)) bgcolor(white) ///
		xscale(range(0 8)) yscale(range(-20 50)) ///
		xmtick(0(2)8) ymtick(-20(10)50) ///
		xlabel(0(2)8) ylabel(-20(10)50) ///
		legend(off) xtitle("Standard error") ytitle("Treatment effect (pp.)") ///
		subtitle("y = `cons' + `beta'x" "     (`consSE')  (`betaSE')", justification(left)) ///
		note("Entire sample: `N' treatments, `cl' trials" "Standard errors clustered by trial in parentheses", justification(left))
	graph export "./output/figures_final/HMB_pubbias.pdf", replace

	**Nudge Units
	clear all
	use "./cleaned_data/NudgeUnits.dta"
	
	qui reg treatmenteffect mde, cluster(trialnumber)
	local cons = string(_b[_cons],"%4.3f")
	local consmde = string(_se[_cons],"%4.3f")
	local beta = string(_b[mde],"%4.3f")
	local betamde = string(_se[mde],"%4.3f")
	local N = e(N)
	local cl = e(N_clust)
	twoway (scatter treatmenteffect mde, mcolor(navy%30)) (lfit treatmenteffect mde), ///
		graphregion(color(white)) bgcolor(white) ///
		xscale(range(0 25)) yscale(range(-20 50)) ///
		xmtick(0(5)25) ymtick(-20(10)50) ///
		xlabel(0(5)25) ylabel(-20(10)50) ///
		legend(off) xtitle("Minimum detectable effect (pp.) with power 0.8") ytitle("Treatment effect (pp.)") ///
		subtitle("y = `cons' + `beta'x" "     (`consmde')  (`betamde')", justification(left)) ///
		note("Entire sample: `N' treatments, `cl' trials" "Standard errors clustered by trial in parentheses", justification(left))
	graph export "./output/figures_final/OESBIT_pubbias_mde.pdf", replace

	qui reg treatmenteffect SE, cluster(trialnumber)
	local cons = string(_b[_cons],"%4.3f")
	local consSE = string(_se[_cons],"%4.3f")
	local beta = string(_b[SE],"%4.3f")
	local betaSE = string(_se[SE],"%4.3f")
	local N = e(N)
	local cl = e(N_clust)
	twoway (scatter treatmenteffect SE, mcolor(navy%30)) (lfit treatmenteffect SE), ///
		graphregion(color(white)) bgcolor(white) ///
		xscale(range(0 8)) yscale(range(-20 50)) ///
		xmtick(0(2)8) ymtick(-20(10)50) ///
		xlabel(0(2)8) ylabel(-20(10)50) ///
		legend(off) xtitle("Standard error") ytitle("Treatment effect (pp.)") ///
		subtitle("y = `cons' + `beta'x" "     (`consSE')  (`betaSE')", justification(left)) ///
		note("Entire sample: `N' treatments, `cl' trials" "Standard errors clustered by trial in parentheses", justification(left))
	graph export "./output/figures_final/OESBIT_pubbias.pdf", replace
	
	qui reg treatmenteffect mde if publication==1, cluster(trialnumber)
	local cons = string(_b[_cons],"%4.3f")
	local consmde = string(_se[_cons],"%4.3f")
	local beta = string(_b[mde],"%4.3f")
	local betamde = string(_se[mde],"%4.3f")
	local N = e(N)
	local cl = e(N_clust)
	twoway (scatter treatmenteffect mde, mcolor(navy%30)) (lfit treatmenteffect mde) if publication==1, ///
		graphregion(color(white)) bgcolor(white) ///
		xscale(range(0 25)) yscale(range(-20 50)) ///
		xmtick(0(5)25) ymtick(-20(10)50) ///
		xlabel(0(5)25) ylabel(-20(10)50) ///
		legend(off) xtitle("Minimum detectable effect (pp.) with power 0.8") ytitle("Treatment effect (pp.)") ///
		subtitle("y = `cons' + `beta'x" "     (`consmde')  (`betamde')", justification(left)) ///
		note("Entire sample: `N' treatments, `cl' trials" "Standard errors clustered by trial in parentheses", justification(left))
	graph export "./output/figures_final/OESBIT_pubbias_published_mde.pdf", replace
}

***********************************
***TABLE 1, A2: NUDGE CATEGORIES***
***********************************
{
	**Nudge Units
	clear all
	use "./cleaned_data/NudgeUnits.dta"
	qui count
	local total=r(N)
	qui distinct trialnumber
	local trials=r(ndistinct)
	egen minsplit = min(trialsplit), by(trialnumber trialsample)
	preserve
		drop if trialsplit!=minsplit
		collapse (mean) controlN (sum) treatmentN, by(trialnumber trialsample)
		gen N = controlN+treatmentN
		qui sum N
	restore
	local totalN = string(round(`r(sum)'),"%12.0gc")

	mata: sum = J(25,7,"")

	mata
		sum[1,1] ="\hspace{1em}Early*"
		sum[2,1] ="\hspace{1em}Recent*"
		
		sum[3,1] ="\hspace{1em}Revenue \& debt"
		sum[4,1] ="\hspace{1em}Benefits \& programs"
		sum[5,1] ="\hspace{1em}Workforce \& education"
		sum[6,1] ="\hspace{1em}Health"
		sum[7,1] ="\hspace{1em}Registration \& regulation compliance"
		sum[8,1] ="\hspace{1em}Community engagement"
		sum[9,1] ="\hspace{1em}Environment"
		sum[10,1]="\hspace{1em}Consumer behavior"

		sum[11,1]="\hspace{1em}Email"
		sum[12,1]="\hspace{1em}Physical letter"
		sum[13,1]="\hspace{1em}Postcard"
		sum[14,1]="\hspace{1em}Website"
		sum[15,1]="\hspace{1em}In person"
		sum[16,1]="\hspace{1em}Other"
		
		sum[17,1]="\hspace{1em}No communication"
		sum[18,1]="\hspace{1em}Some communication"
		
		sum[19,1]="\hspace{1em}Simplification \& information"
		sum[20,1]="\hspace{1em}Personal motivation"
		sum[21,1]="\hspace{1em}Reminders \& planning prompts"
		sum[22,1]="\hspace{1em}Social cues"
		sum[23,1]="\hspace{1em}Framing \& formatting"
		sum[24,1]="\hspace{1em}Choice design"
		
		sum[25,1]="Total"
	end

	mata: sum[25,2]="100"
	mata: sum[25,3]="`total'"+" ("+"`trials'"+")"
	qui sum treatmenteffect
	local ate=string(`r(mean)',"%4.2f")
	mata: sum[25,4]="`ate'"

	*Date
	gen recent = 0 if year<=2016
	replace recent = 1 if year>2016
	forvalues i=0/1 {
		qui count if recent==`i'
		local count=r(N)
		qui distinct trialnumber if recent==`i'
		local trials=r(ndistinct)
		local freq=string(100*`count'/`total',"%4.2f")
		qui sum treatmenteffect if recent==`i'
		local ate=string(`r(mean)',"%4.2f")
		mata: sum[1+`i',2]="`freq'"
		mata: sum[1+`i',3]="`count'"+" ("+"`trials'"+")"
		mata: sum[1+`i',4]="`ate'"
	}

	*Policy area
	local policylist `" "Revenue collection and debt repayment" "Take-up of benefits and programs" "Workforce and education" "Health" "Registration and regulation compliance" "Community engagement"  "Environment" "'
	forvalues i=1/7 {
		local x: word `i' of `policylist'
		qui count if policyarea=="`x'"
		local count=r(N)
		qui distinct trialnumber if policyarea=="`x'"
		local trials=r(ndistinct)
		local freq=string(100*`count'/`total',"%4.2f")
		qui sum treatmenteffect if policyarea=="`x'"
		local ate=string(`r(mean)',"%4.2f")
		mata: sum[2+`i',2]="`freq'"
		mata: sum[2+`i',3]="`count'"+" ("+"`trials'"+")"
		mata: sum[2+`i',4]="`ate'"
	}
	mata
		sum[10,2]="0"
		sum[10,3]="0 (0)"
		sum[10,4]="--"
	end

	*Control communication 
	forvalues i=0/1 {
		qui count if controlreceivescomm==`i'
		local count=r(N)
		qui distinct trialnumber if controlreceivescomm==`i'
		local trials=r(ndistinct)
		local freq=string(100*`count'/`total',"%4.2f")
		qui sum treatmenteffect if controlreceivescomm==`i'
		local ate=string(`r(mean)',"%4.2f")
		mata: sum[17+`i',2]="`freq'"
		mata: sum[17+`i',3]="`count'"+" ("+"`trials'"+")"
		mata: sum[17+`i',4]="`ate'"
	}

	*Medium
	local medlist medium_email medium_physicalletter medium_postcard medium_website medium_inperson medium_other
	forvalues i=1/6 {
		local x: word `i' of `medlist'
		qui count if `x'==1
		local count=r(N)
		qui distinct trialnumber if `x'==1
		local trials=r(ndistinct)
		local freq=string(100*`count'/`total',"%4.2f")
		qui sum treatmenteffect if `x'==1
		local ate=string(`r(mean)',"%4.2f")
		mata: sum[10+`i',2]="`freq'"
		mata: sum[10+`i',3]="`count'"+" ("+"`trials'"+")"
		mata: sum[10+`i',4]="`ate'"
	}

	* Mechanism
	local mechlist mech_simplification mech_personalmotivation mech_planning mech_socialcues mech_framing mech_choicedesign     
	forvalues i=1/6 {
		local x: word `i' of `mechlist'
		qui count if `x'==1
		local count=r(N)
		qui distinct trialnumber if `x'==1
		local trials=r(ndistinct)
		local freq=string(100*`count'/`total',"%4.2f")
		qui sum treatmenteffect if `x'==1
		local ate=string(`r(mean)',"%4.2f")
		mata: sum[18+`i',2]="`freq'"
		mata: sum[18+`i',3]="`count'"+" ("+"`trials'"+")"
		mata: sum[18+`i',4]="`ate'"
	}

	**Academic Journals
	use "./cleaned_data/AcademicJournals.dta", clear

	qui count
	local total=r(N)
	qui distinct trialnumber
	local trials=r(ndistinct)
	preserve
		collapse (mean) controlN (sum) treatmentN, by(trialnumber trialsample)
		gen N = controlN+treatmentN
		qui sum N
	restore
	local totalN = string(round(`r(sum)'),"%12.0gc")

	mata: sum[25,5]="100"
	mata: sum[25,6]="`total'"+" ("+"`trials'"+")"
	qui sum treatmenteffect
	local ate=string(`r(mean)',"%4.2f")
	mata: sum[25,7]="`ate'"

	*Date
	gen recent = 0 if year<=2014
	replace recent = 1 if year>2014
	forvalues i=0/1 {
		qui count if recent==`i'
		local count=r(N)
		qui distinct trialnumber if recent==`i'
		local trials=r(ndistinct)
		local freq=string(100*`count'/`total',"%4.2f")
		qui sum treatmenteffect if recent==`i'
		local ate=string(`r(mean)',"%4.2f")
		mata: sum[1+`i',5]="`freq'"
		mata: sum[1+`i',6]="`count'"+" ("+"`trials'"+")"
		mata: sum[1+`i',7]="`ate'"
	}

	*Policy area
	local policylist `" "Revenue collection and debt repayment" "Take-up of benefits and programs" "Workforce and education" "Health" "Registration and regulation compliance" "Community engagement"  "Environment" "Consumer behavior" "'
	forvalues i=1/8 {
		local x: word `i' of `policylist'
		qui count if policyarea=="`x'"
		local count=r(N)
		qui distinct trialnumber if policyarea=="`x'"
		local trials=r(ndistinct)
		local freq=string(100*`count'/`total',"%4.2f")
		qui sum treatmenteffect if policyarea=="`x'"
		local ate=string(`r(mean)',"%4.2f")
		mata: sum[2+`i',5]="`freq'"
		mata: sum[2+`i',6]="`count'"+" ("+"`trials'"+")"
		mata: sum[2+`i',7]="`ate'"
	}

	*Control communication 
	forvalues i=0/1 {
		qui count if controlreceivescomm==`i'
		local count=r(N)
		qui distinct trialnumber if controlreceivescomm==`i'
		local trials=r(ndistinct)
		local freq=string(100*`count'/`total',"%4.2f")
		qui sum treatmenteffect if controlreceivescomm==`i'
		local ate=string(`r(mean)',"%4.2f")
		mata: sum[17+`i',5]="`freq'"
		mata: sum[17+`i',6]="`count'"+" ("+"`trials'"+")"
		mata: sum[17+`i',7]="`ate'"
	}

	*Medium
	local medlist medium_email medium_physicalletter medium_postcard medium_website medium_inperson medium_other
	forvalues i=1/6 {
		local x: word `i' of `medlist'
		qui count if `x'==1
		local count=r(N)
		qui distinct trialnumber if `x'==1
		local trials=r(ndistinct)
		local freq=string(100*`count'/`total',"%4.2f")
		qui sum treatmenteffect if `x'==1
		local ate=string(`r(mean)',"%4.2f")
		mata: sum[10+`i',5]="`freq'"
		mata: sum[10+`i',6]="`count'"+" ("+"`trials'"+")"
		mata: sum[10+`i',7]="`ate'"
	}

	*Mechanism
	local mechlist mech_simplification mech_personalmotivation mech_planning mech_socialcues mech_framing mech_choicedesign     
	forvalues i=1/6 {
		local x: word `i' of `mechlist'
		qui count if `x'==1
		local count=r(N)
		qui distinct trialnumber if `x'==1
		local trials=r(ndistinct)
		local freq=string(100*`count'/`total',"%4.2f")
		qui sum treatmenteffect if `x'==1
		local ate=string(`r(mean)',"%4.2f")
		mata: sum[18+`i',5]="`freq'"
		mata: sum[18+`i',6]="`count'"+" ("+"`trials'"+")"
		mata: sum[18+`i',7]="`ate'"
	}

	mmat2tex sum using "./output/tables_final/SummaryStats_comb.tex", ///
		replace ///
		preheader(\begin{table}[htbp!] ///
			\centering \large{\begin{threeparttable} ///
			\caption{Comparison of nudge categories} ///
			\begin{tabular} {l c c c c c c} \toprule ///
			& \multicolumn{3}{c}{Nudge Units} & \multicolumn{3}{c}{Academic Journals} \\ ///
			\cmidrule(lr){2-4} \cmidrule(lr){5-7} ///
			& Freq. (\%) & Nudges (Trials) & ATE (pp.) & Freq. (\%) & Nudges (Trials) & ATE (pp.) \\ \hline ///
			) ///
		insertendrow(1 "\multicolumn{7}{l}{\textit{Date}} \\" ///
					 3 "\multicolumn{7}{l}{\textit{Policy area}} \\" ///
					17 "\multicolumn{7}{l}{\textit{Control group receives:}} \\" /// 
					11 "\multicolumn{7}{l}{\textit{Medium of communication}} \\" ///
					19 "\multicolumn{7}{l}{\textit{Mechanism}} \\" ///
					25 "\hline") ///	
		bottom(\bottomrule \end{tabular} \label{tab:summary} ///
		\begin{tablenotes} \small ///
		\item This table shows the number of nudges and trials in each category, and the average treatment effect within each category. ///
				Frequencies for \textit{Medium} and \textit{Mechanism} are not mutually exclusive and frequencies may not sum to 1. ///
		\item *\textit{Early} refers to trials implemented between 2015-2016 for Nudge Units, and to papers published in 2014 or before for Academic Journals. ///
				\textit{Recent} refers to trials and papers after these dates. ///
		\end{tablenotes} \end{threeparttable}} \end{table})

	***Appendix table
	**Nudge Units
	clear all
	use "./cleaned_data/NudgeUnits.dta"
	qui count
	local total=r(N)
	qui sum controltakeup
	local c=string(`r(mean)',"%4.2f")
	egen minsplit = min(trialsplit), by(trialnumber trialsample)
	preserve
		drop if trialsplit!=minsplit
		collapse (mean) controlN (sum) treatmentN, by(trialnumber trialsample)
		gen N = controlN+treatmentN
		qui sum N
	restore
	local totalN = string(round(`r(sum)'),"%12.0gc")

	mata: sum = J(25,7,"")

	mata
		sum[1,1] ="\hspace{1em}Early*"
		sum[2,1] ="\hspace{1em}Recent*"
		
		sum[3,1] ="\hspace{1em}Revenue \& debt"
		sum[4,1] ="\hspace{1em}Benefits \& programs"
		sum[5,1] ="\hspace{1em}Workforce \& education"
		sum[6,1] ="\hspace{1em}Health"
		sum[7,1] ="\hspace{1em}Registration \& regulation compliance"
		sum[8,1] ="\hspace{1em}Community engagement"
		sum[9,1] ="\hspace{1em}Environment"
		sum[10,1]="\hspace{1em}Consumer behavior"
		
		sum[17,1]="\hspace{1em}No communication"
		sum[18,1]="\hspace{1em}Some communication"
		
		sum[11,1]="\hspace{1em}Email"
		sum[12,1]="\hspace{1em}Physical letter"
		sum[13,1]="\hspace{1em}Postcard"
		sum[14,1]="\hspace{1em}Website"
		sum[15,1]="\hspace{1em}In person"
		sum[16,1]="\hspace{1em}Other"
		
		sum[19,1]="\hspace{1em}Simplification \& information"
		sum[20,1]="\hspace{1em}Personal motivation"
		sum[21,1]="\hspace{1em}Reminders \& planning prompts"
		sum[22,1]="\hspace{1em}Social cues"
		sum[23,1]="\hspace{1em}Framing \& formatting"
		sum[24,1]="\hspace{1em}Choice design"
		
		sum[25,1]="Total"
	end

	mata: sum[25,2]="100"
	mata: sum[25,3]="`c'"
	mata: sum[25,4]="`totalN'"+" (sum)"

	*Date
	gen recent = 0 if year<=2016
	replace recent = 1 if year>2016
	forvalues i=0/1 {
		qui count if recent==`i'
		local count=r(N)
		qui sum controltakeup if recent==`i'
		local c=string(`r(mean)',"%4.2f")
		local freq=string(100*`count'/`total',"%4.2f")
		preserve
			drop if trialsplit!=minsplit | recent!=`i'
			collapse (mean) controlN (sum) treatmentN, by(trialnumber trialsample)
			gen N = controlN+treatmentN
			qui sum N
		restore
		local N = string(round(`r(mean)'),"%12.0gc")
		mata: sum[1+`i',2]="`freq'"
		mata: sum[1+`i',3]="`c'"
		mata: sum[1+`i',4]="`N'"
	}

	*Policy area
	local policylist `" "Revenue collection and debt repayment" "Take-up of benefits and programs" "Workforce and education" "Health" "Registration and regulation compliance" "Community engagement"  "Environment" "'
	forvalues i=1/7 {
		local x: word `i' of `policylist'
		qui count if policyarea=="`x'"
		local count=r(N)
		qui sum controltakeup if policyarea=="`x'"
		local c=string(`r(mean)',"%4.2f")
		local freq=string(100*`count'/`total',"%4.2f")
		preserve
			drop if trialsplit!=minsplit | policyarea!="`x'"
			collapse (mean) controlN (sum) treatmentN, by(trialnumber trialsample)
			gen N = controlN+treatmentN
			qui sum N
		restore
		local N = string(round(`r(mean)'),"%12.0gc")
		mata: sum[2+`i',2]="`freq'"
		mata: sum[2+`i',3]="`c'"
		mata: sum[2+`i',4]="`N'"
	}
	mata
		sum[10,2]="0"
		sum[10,3]="--"
		sum[10,4]="0"
	end

	*Control communication 
	forvalues i=0/1 {
		qui count if controlreceivescomm==`i'
		local count=r(N)
		qui sum controltakeup if controlreceivescomm==`i'
		local c=string(`r(mean)',"%4.2f")
		local freq=string(100*`count'/`total',"%4.2f")
		preserve
			drop if trialsplit!=minsplit | controlreceivescomm!=`i'
			collapse (mean) controlN (sum) treatmentN, by(trialnumber trialsample)
			gen N = controlN+treatmentN
			qui sum N
		restore
		local N = string(round(`r(mean)'),"%12.0gc")
		mata: sum[17+`i',2]="`freq'"
		mata: sum[17+`i',3]="`c'"
		mata: sum[17+`i',4]="`N'"
	}

	*Medium
	local medlist medium_email medium_physicalletter medium_postcard medium_website medium_inperson medium_other
	forvalues i=1/6 {
		local x: word `i' of `medlist'
		qui count if `x'==1
		local count=r(N)
		qui sum controltakeup if `x'==1
		local c=string(`r(mean)',"%4.2f")
		local freq=string(100*`count'/`total',"%4.2f")
		preserve
			drop if trialsplit!=minsplit | `x'!=1
			collapse (mean) controlN (sum) treatmentN, by(trialnumber trialsample)
			gen N = controlN+treatmentN
			qui sum N
		restore
		local N = string(round(`r(mean)'),"%12.0gc")
		mata: sum[10+`i',2]="`freq'"
		mata: sum[10+`i',3]="`c'"
		mata: sum[10+`i',4]="`N'"
	}

	* Mechanism
	local mechlist mech_simplification mech_personalmotivation mech_planning mech_socialcues mech_framing mech_choicedesign     
	forvalues i=1/6 {
		local x: word `i' of `mechlist'
		qui count if `x'==1
		local count=r(N)
		qui sum controltakeup if `x'==1
		local c=string(`r(mean)',"%4.2f")
		local freq=string(100*`count'/`total',"%4.2f")
		preserve
			drop if trialsplit!=minsplit | `x'!=1
			collapse (mean) controlN (sum) treatmentN, by(trialnumber trialsample)
			gen N = controlN+treatmentN
			qui sum N
		restore
		local N = string(round(`r(mean)'),"%12.0gc")
		mata: sum[18+`i',2]="`freq'"
		mata: sum[18+`i',3]="`c'"
		mata: sum[18+`i',4]="`N'"
	}

	*** Academic Journals
	use "./cleaned_data/AcademicJournals.dta", clear

	qui count
	local total=r(N)
	bysort trialnumber: gen n=_n
	qui sum controltakeup
	local c=string(`r(mean)',"%4.2f")
	preserve
		collapse (mean) controlN (sum) treatmentN, by(trialnumber trialsample)
		gen N = controlN+treatmentN
		qui sum N
	restore
	local totalN = string(round(`r(sum)'),"%12.0gc")

	mata: sum[25,5]="100"
	mata: sum[25,6]="`c'"
	mata: sum[25,7]="`totalN'"+" (sum)"

	*Date
	gen recent = 0 if year<=2014
	replace recent = 1 if year>2014
	forvalues i=0/1 {
		qui count if recent==`i'
		local count=r(N)
		qui sum controltakeup if recent==`i'
		local c=string(`r(mean)',"%4.2f")
		local freq=string(100*`count'/`total',"%4.2f")
		preserve
			drop if recent!=`i'
			collapse (mean) controlN (sum) treatmentN, by(trialnumber trialsample)
			gen N = controlN+treatmentN
			qui sum N
		restore
		local N = string(round(`r(mean)'),"%12.0gc")
		mata: sum[1+`i',5]="`freq'"
		mata: sum[1+`i',6]="`c'"
		mata: sum[1+`i',7]="`N'"
	}

	*Policy area
	local policylist `" "Revenue collection and debt repayment" "Take-up of benefits and programs" "Workforce and education" "Health" "Registration and regulation compliance" "Community engagement"  "Environment" "Consumer behavior" "'
	forvalues i=1/8 {
		local x: word `i' of `policylist'
		qui count if policyarea=="`x'"
		local count=r(N)
		qui sum controltakeup if policyarea=="`x'"
		local c=string(`r(mean)',"%4.2f")
		local freq=string(100*`count'/`total',"%4.2f")
		preserve
			drop if policyarea!="`x'"
			collapse (mean) controlN (sum) treatmentN, by(trialnumber trialsample)
			gen N = controlN+treatmentN
			qui sum N
		restore
		local N = string(round(`r(mean)'),"%12.0gc")
		mata: sum[2+`i',5]="`freq'"
		mata: sum[2+`i',6]="`c'"
		mata: sum[2+`i',7]="`N'"
	}

	*Control communication 
	forvalues i=0/1 {
		qui count if controlreceivescomm==`i'
		local count=r(N)
		qui sum controltakeup if controlreceivescomm==`i'
		local c=string(`r(mean)',"%4.2f")
		local freq=string(100*`count'/`total',"%4.2f")
		preserve
			drop if controlreceivescomm!=`i'
			collapse (mean) controlN (sum) treatmentN, by(trialnumber trialsample)
			gen N = controlN+treatmentN
			qui sum N
		restore
		local N = string(round(`r(mean)'),"%12.0gc")
		mata: sum[17+`i',5]="`freq'"
		mata: sum[17+`i',6]="`c'"
		mata: sum[17+`i',7]="`N'"
	}

	*Medium
	local medlist medium_email medium_physicalletter medium_postcard medium_website medium_inperson medium_other
	forvalues i=1/6 {
		local x: word `i' of `medlist'
		qui count if `x'==1
		local count=r(N)
		qui sum controltakeup if `x'==1
		local c=string(`r(mean)',"%4.2f")
		local freq=string(100*`count'/`total',"%4.2f")
		preserve
			drop if `x'!=1
			collapse (mean) controlN (sum) treatmentN, by(trialnumber trialsample)
			gen N = controlN+treatmentN
			qui sum N
		restore
		local N = string(round(`r(mean)'),"%12.0gc")
		mata: sum[10+`i',5]="`freq'"
		mata: sum[10+`i',6]="`c'"
		mata: sum[10+`i',7]="`N'"
	}

	*Mechanism
	local mechlist mech_simplification mech_personalmotivation mech_planning mech_socialcues mech_framing mech_choicedesign     
	forvalues i=1/6 {
		local x: word `i' of `mechlist'
		qui count if `x'==1
		local count=r(N)
		qui sum controltakeup if `x'==1
		local c=string(`r(mean)',"%4.2f")
		local freq=string(100*`count'/`total',"%4.2f")
		preserve
			drop if `x'!=1
			collapse (mean) controlN (sum) treatmentN, by(trialnumber trialsample)
			gen N = controlN+treatmentN
			qui sum N
		restore
		local N = string(round(`r(mean)'),"%12.0gc")
		mata: sum[18+`i',5]="`freq'"
		mata: sum[18+`i',6]="`c'"
		mata: sum[18+`i',7]="`N'"
	}

	mmat2tex sum using "./output/tables_final/SummaryStats_appendix.tex", ///
		replace ///
		preheader(\begin{table}[htbp!] ///
			\centering \begin{threeparttable} ///
			\caption{Comparison of nudge categories} ///
			\begin{tabular} {l c c c c c c} \toprule ///
			& \multicolumn{3}{c}{Nudge Units} & \multicolumn{3}{c}{Academic Journals} \\ ///
			\cmidrule(lr){2-4} \cmidrule(lr){5-7} ///
			& Freq. (\%) & Control take-up (\%) & Trial-level \textit{N} & Freq. (\%) & Control take-up (\%) & Trial-level \textit{N} \\ \hline ///
			) ///
		insertendrow(1 "\multicolumn{7}{l}{\textit{Date}} \\" ///
					 3 "\multicolumn{7}{l}{\textit{Policy area}} \\" ///
					17 "\multicolumn{7}{l}{\textit{Control group receives:}} \\" /// 
					11 "\multicolumn{7}{l}{\textit{Medium of communication}} \\" ///
					19 "\multicolumn{7}{l}{\textit{Mechanism}} \\" ///
					25 "\hline") ///	
		bottom(\bottomrule \end{tabular} \label{tab:summary_app} ///
		\begin{tablenotes} \small ///
		\item This table shows the frequency of nudges in each category, and the average control group take-up and trial-level \textit{N} within each category. ///
				Frequencies for \textit{Medium} and \textit{Mechanism} are not mutually exclusive and frequencies may not sum to 1. ///
		\item *\textit{Early} refers to trials implemented between 2015-2016 for Nudge Units, and to papers published in 2014 or before for Academic Journals. ///
				\textit{Recent} refers to trials and papers after these dates. ///
		\end{tablenotes} \end{threeparttable} \end{table})
}		
********************************************
***TABLE 2, FIGURES A4b,c: TRIAL FEATURES***
********************************************
/*
NOTE: The responses to the researcher survey (i.e., variables survey_*)
have been redacted for confidentiality. As a result,
the code for Table 2 will not run on this redacted data file.
*/
{
/*
	clear all
	mata: table=J(24,6,"")
	
	**Column 1
	use "./cleaned_data/AcademicJournals.dta"
	replace outcomedurationdays=360 if outcomedurationdays>360 & outcomedurationdays!=. // winsorize outcome duration at 1 year
	bysort trialnumber: gen n=_n // condition on n==1 for trial-level variables
	bysort trialnumber: gen arms=_N	// number of treatment arms in a trial across different samples within a trial
	egen mechs=rowtotal(mech*)
	
	qui sum arms if n==1, d
	local mean = string(`r(mean)',"%4.1f")
	local sd = string(`r(sd)',"%4.1f")
	mata: table[7,2]="`mean'"
	mata: table[8,2]="\small{["+"`sd'"+"]}"

	local varlist mechs controltakeup mde
	local rowlist 5 1 9
	local i=1
	foreach var in `varlist' {
		local r: word `i' of `rowlist'
		qui sum `var', d
		local mean = string(`r(mean)',"%4.1f")
		local sd = string(`r(sd)',"%4.1f")
		mata: table[`r',2]="`mean'"
		mata: table[`r'+1,2]="\small{["+"`sd'"+"]}"
		local ++i
	}

	local varlist outcomedurationdays survey_durationtotal survey_durationplanning survey_durationdata survey_durationwriting survey_FTE survey_constraints
	local rowlist 3 13 15 17 19 21 11
	local i=1
	foreach var in `varlist' {
		local r: word `i' of `rowlist'
		qui sum `var' if n==1, d
		local mean = string(`r(mean)',"%4.1f")
		local sd = string(`r(sd)',"%4.1f")
		
		mata: table[`r',2]="`mean'"
		mata: table[`r'+1,2]="\small{["+"`sd'"+"]}"
		local ++i
	}

	qui count if n==1 & survey_durationtotal!=.
	local count = string(`r(N)',"%3.0f")
	mata: table[23,2]="`count'"
	qui count if n==1
	local count = string(`r(N)',"%3.0f")
	mata: table[24,2]="`count'"
	
	**Columns 2-5
	use "./cleaned_data/NudgeUnits.dta", clear
	gen AJ = 0
	append using "./cleaned_data/AcademicJournals.dta", force
	replace AJ = 1 if missing(AJ)
	label var AJ "Acad. Jour."
	replace outcomedurationdays=360 if outcomedurationdays>360 & outcomedurationdays!=. // winsorize outcome duration at 1 year
	bysort trialnumber: gen n=_n // condition on n==1 for trial-level variables
	bysort trialnumber: gen arms=_N // number of treatment arms in a trial across different samples within a trial
	egen mechs=rowtotal(mech*)
	
	*Column 1
	qui sum arms if n==1 & AJ==0, d
	local mean = string(`r(mean)',"%4.1f")
	local sd = string(`r(sd)',"%4.1f")
	qui reg arms 0.AJ if n==1, r
	local pval = (2*ttail(e(df_r),abs(_b[0.AJ]/_se[0.AJ])))
	local pval = string(`pval',"%3.2f")

	mata: table[7,3]="`mean'"
	mata: table[8,3]="\small{["+"`sd'; "+"\textit{p}=`pval'"+"]}"

	local varlist mechs controltakeup mde
	local rowlist 5 1 9
	local i=1
	foreach var in `varlist' {
		local r: word `i' of `rowlist'
		qui sum `var' if AJ==0, d // & publication==1
		local mean = string(`r(mean)',"%4.1f")
		local sd = string(`r(sd)',"%4.1f")
		qui reg `var' 0.AJ, cl(trialnumber)
		local pval = (2*ttail(e(df_r),abs(_b[0.AJ]/_se[0.AJ])))
		local pval = string(`pval',"%3.2f")
		mata: table[`r',3]="`mean'"
		mata: table[`r'+1,3]="\small{["+"`sd'; "+"\textit{p}=`pval'"+"]}"
		local ++i
	}

	qui sum outcomedurationdays if n==1 & AJ==0, d
	local mean = string(`r(mean)',"%4.1f")
	local sd = string(`r(sd)',"%4.1f")
	qui reg outcomedurationdays 0.AJ if n==1, r
	local pval = (2*ttail(e(df_r),abs(_b[0.AJ]/_se[0.AJ])))
	local pval = string(`pval',"%3.2f")
	mata: table[3,3]="`mean'"
	mata: table[4,3]="\small{["+"`sd'; "+"\textit{p}=`pval'"+"]}"
	 
	qui count if n==1 & AJ==0
	local count = string(`r(N)',"%3.0f")
	mata: table[24,3]="`count'"
	
	*Column 5
	qui sum arms if n==1 & academicaffil==1 & AJ==0, d
	local mean = string(`r(mean)',"%4.1f")
	local sd = string(`r(sd)',"%4.1f")
	qui reg arms 0.AJ if n==1 & (academicaffil==1|AJ==1), r
	local pval = (2*ttail(e(df_r),abs(_b[0.AJ]/_se[0.AJ])))
	local pval = string(`pval',"%3.2f")

	mata: table[7,6]="`mean'"
	mata: table[8,6]="\small{["+"`sd'; "+"\textit{p}=`pval'"+"]}"

	local varlist mechs controltakeup mde
	local rowlist 5 1 9
	local i=1
	foreach var in `varlist' {
		local r: word `i' of `rowlist'
		qui sum `var' if academicaffil==1 & AJ==0, d
		local mean = string(`r(mean)',"%4.1f")
		local sd = string(`r(sd)',"%4.1f")
		qui reg `var' 0.AJ if (academicaffil==1|AJ==1), cl(trialnumber)
		local pval = (2*ttail(e(df_r),abs(_b[0.AJ]/_se[0.AJ])))
		local pval = string(`pval',"%3.2f")
		mata: table[`r',6]="`mean'"
		mata: table[`r'+1,6]="\small{["+"`sd'; "+"\textit{p}=`pval'"+"]}"
		local ++i
	}

	local varlist outcomedurationdays survey_durationtotal survey_durationplanning survey_durationdata survey_durationwriting survey_FTE survey_constraints
	local rowlist 3 13 15 17 19 21 11
	local i=1
	foreach var in `varlist' {
		local r: word `i' of `rowlist'
		qui sum `var' if n==1 & academicaffil==1 & AJ==0, d
		local mean = string(`r(mean)',"%4.1f")
		local sd = string(`r(sd)',"%4.1f")
		qui reg `var' 0.AJ if n==1 & (academicaffil==1|AJ==1), r
		local pval = (2*ttail(e(df_r),abs(_b[0.AJ]/_se[0.AJ])))
		local pval = string(`pval',"%3.2f")
		mata: table[`r',6]="`mean'"
		mata: table[`r'+1,6]="\small{["+"`sd'; "+"\textit{p}=`pval'"+"]}"
		local ++i
	}
	qui count if n==1 & academicaffil==1 & survey_durationtotal!=. & AJ==0
	local count = string(`r(N)',"%3.0f")
	mata: table[23,6]="`count'"
	qui count if n==1 & academicaffil==1 & AJ==0
	local count = string(`r(N)',"%3.0f")
	mata: table[24,6]="`count'"
	
	*Columns 3-4
	forvalues g=0/1{
		qui sum arms if n==1 & OES==`g' & AJ==0, d
		local mean = string(`r(mean)',"%4.1f")
		local sd = string(`r(sd)',"%4.1f")
		qui reg arms 0.AJ if n==1 & (OES==`g'|AJ==1), r
		local pval = (2*ttail(e(df_r),abs(_b[0.AJ]/_se[0.AJ])))
		local pval = string(`pval',"%3.2f")
		
		mata: table[7,4+`g']="`mean'"
		mata: table[8,4+`g']="\small{["+"`sd'; "+"\textit{p}=`pval'"+"]}"
		
		local varlist mechs controltakeup mde
		local rowlist 5 1 9
		local i=1
		foreach var in `varlist' {
			local r: word `i' of `rowlist'
			qui sum `var' if OES==`g' & AJ==0, d
			local mean = string(`r(mean)',"%4.1f")
			local sd = string(`r(sd)',"%4.1f")
			qui reg `var' 0.AJ if (OES==`g'|AJ==1), cl(trialnumber)
			local pval = (2*ttail(e(df_r),abs(_b[0.AJ]/_se[0.AJ])))
			local pval = string(`pval',"%3.2f")
			mata: table[`r',4+`g']="`mean'"
			mata: table[`r'+1,4+`g']="\small{["+"`sd'; "+"\textit{p}=`pval'"+"]}"
			local ++i
		}	

		qui sum outcomedurationdays if n==1 & OES==`g' & AJ==0, d
		local mean = string(`r(mean)',"%4.1f")
		local sd = string(`r(sd)',"%4.1f")
		qui reg outcomedurationdays 0.AJ if n==1 & (OES==`g'|AJ==1), r
		local pval = (2*ttail(e(df_r),abs(_b[0.AJ]/_se[0.AJ])))
		local pval = string(`pval',"%3.2f")
		
		mata: table[3,4+`g']="`mean'"
		mata: table[4,4+`g']="\small{["+"`sd'; "+"\textit{p}=`pval'"+"]}"
		
		qui count if n==1 & OES==`g' & AJ==0
		local count = string(`r(N)',"%3.0f")
		mata: table[24,4+`g']="`count'"
	}
	
	*Figures A4b,c
	cumul mechs if AJ==0, gen(cumulmechsNU)
	cumul mechs if AJ==1, gen(cumulmechsAJ)
	cumul arms if AJ==0 & n==1, gen(cumularmsNU)
	cumul arms if AJ==1 & n==1, gen(cumularmsAJ)
	qui sum mechs if AJ==0
	local mechNU=string(`r(mean)',"%4.2f")
	local mechNUx=`r(mean)'+0.1
	qui sum mechs if AJ==1
	local mechAJ=string(`r(mean)',"%4.2f")
	local mechAJx=`r(mean)'+0.1
	qui sum arms if AJ==0 & n==1
	local armsNU=string(`r(mean)',"%4.2f")
	local armsNUx=`r(mean)'+0.1
	qui sum arms if AJ==1 & n==1
	local armsAJ=string(`r(mean)',"%4.2f")
	local armsAJx=`r(mean)'+0.1
	twoway (line cumulmechsNU mechs if AJ==0 & mechs>0, sort(cumulmechsNU) lcolor(blue) lwidth(thick)) ///
			(line cumulmechsAJ mechs if AJ==1, sort(cumulmechsAJ) lcolor(red)), ///
			graphregion(color(white)) bgcolor(white) ytitle("CDF") ///
			xtitle("Number of mechanisms per treatment arm") ///
			legend(order(1 "Nudge Units" 2 "Academic Journals")) ///
			xline(`mechAJ', lpattern(dash) lcolor(red)) ///
			xline(`mechNU', lpattern(dash) lcolor(blue) lwidth(thick)) ///
			text(1 `mechAJx' "{&larr}mean (`mechAJ' pp.)", place(e) color(red) size(small) box bcolor(white)) ///
			text(0.5 `mechNUx' "{&larr}mean (`mechNU' pp.)", place(e) color(blue) size(small) box bcolor(white))
	graph export "./output/figures_final/mechs_cdf.png", replace
	twoway (line cumularmsNU arms if AJ==0 & n==1 & arms<=7, sort(cumularmsNU) lcolor(blue) lwidth(thick)) ///
			(line cumularmsAJ arms if AJ==1 & n==1, sort(cumularmsAJ) lcolor(red)), ///
			graphregion(color(white)) bgcolor(white) ytitle("CDF") ///
			xtitle("Number of treatment arms per trial") ///
			legend(order(1 "Nudge Units" 2 "Academic Journals")) ///
			xscale(range(1(1)7)) xticks(1(1)7) xlabel(1(1)7) ///
			xline(`armsAJ', lpattern(dash) lcolor(red)) ///
			xline(`armsNU', lpattern(dash) lcolor(blue) lwidth(thick)) ///
			text(0.5 `armsAJx' "{&larr}mean (`armsAJ' pp.)", place(e) color(red) size(small) box bcolor(white)) ///
			text(1 `armsNUx' "{&larr}mean (`armsNU' pp.)", place(e) color(blue) size(small) box bcolor(white))
	graph export "./output/figures_final/arms_cdf.png", replace
	drop cumul*
	
	keep if AJ==1 & n==1
	keep AJ survey_durationtotal survey_durationplanning survey_durationdata survey_durationwriting survey_FTE survey_constraints
	tempfile x
	save `x', replace
	use "./cleaned_data/OES_Survey.dta", clear
	gen OES=1
	append using "./cleaned_data/BIT_Survey.dta", force
	replace OES=0 if OES==.
	gen AJ=0
	append using `x', force

	local varlist survey_durationtotal survey_durationplanning survey_durationdata survey_durationwriting survey_FTE survey_constraints
	local rowlist 13 15 17 19 21 11
	local i=1
	foreach var in `varlist' {
		local r: word `i' of `rowlist'
		qui sum `var' if AJ==0, d
		local mean = string(`r(mean)',"%4.1f")
		local sd = string(`r(sd)',"%4.1f")
		qui reg `var' 0.AJ, r
		local pval = (2*ttail(e(df_r),abs(_b[0.AJ]/_se[0.AJ])))
		local pval = string(`pval',"%3.2f")
		mata: table[`r',3]="`mean'"
		mata: table[`r'+1',3]="\small{["+"`sd'; "+"\textit{p}=`pval'"+"]}"
		local ++i
	}
	qui count if AJ==0
	local count = string(`r(N)',"%3.0f")
	mata: table[23,3]="`count'"+"*"

	forvalues g=0/1 {
		local i=1
		foreach var in `varlist' {
			local r: word `i' of `rowlist'
			qui sum `var' if OES==`g', d
			local mean = string(`r(mean)',"%4.1f")
			local sd = string(`r(sd)',"%4.1f")
			qui reg `var' 0.AJ if OES==`g'|AJ==1, r
			local pval = (2*ttail(e(df_r),abs(_b[0.AJ]/_se[0.AJ])))
			local pval = string(`pval',"%3.2f")
			mata: table[`r',4+`g']="`mean'"
			mata: table[`r'+1,4+`g']="\small{["+"`sd'; "+"\textit{p}=`pval'"+"]}"
			local ++i
		}
		qui count if OES==`g'
		local count = string(`r(N)',"%3.0f")
		mata: table[23,4+`g']="`count'"+"*"
	}

		mata
		table[1,1]="\hspace{1em}Control group take-up (\%)"
		table[3,1]="\hspace{1em}Outcome time-frame (days)"
		table[5,1]="\hspace{1em}Mechanisms per treatment arm"
		table[7,1]="\hspace{1em}Treatment arms per trial"
		table[9,1]="\hspace{1em}Minimum detectable effect (pp.)"
		table[11,1]="\hspace{1em}Institutional constraints rating (1-5)"
		table[13,1]="\hspace{1em}Total duration (months)"
		table[15,1]="\hspace{2em}Planning (including IRB)"
		table[17,1]="\hspace{2em}Intervention and data collection"
		table[19,1]="\hspace{2em}Data analysis and write-up"
		table[21,1]="\hspace{1em}Personnel full-time equivalent months"
		table[23,1]="Number of survey responses"
		table[24,1]="Number of trials"	
	end

	mmat2tex table using "./output/tables_final/Survey_mean.tex", ///
		replace ///
		preheader(\begin{table}[htbp!] \centering \large{\begin{threeparttable} ///
		\caption{Comparison of trial features} \begin{tabular} {l c c c c c} \toprule ///
		& Academic Journals & \multicolumn{4}{c}{Nudge Units} \\ ///
		& \small{Mean [std. dev.]} & \multicolumn{4}{c}{\small{Mean [std. dev.; \textit{p}-value of difference from column 1]}} \\ ///
		\cmidrule(lr){2-2} \cmidrule(lr){3-6} ///
		& & All & BIT & OES & Academic-affiliated OES \\ ///
		& (1) & (2) & (3) & (4) & (5) \\ \hline ///
		\textit{Academic faculty involvement} & 100\% & 19\% & 0\% & 50\% & 100\% \\ ///
		\multicolumn{6}{l}{\textit{Outcome features}} \\) ///
		insertendrow(	5 "\multicolumn{6}{l}{\textit{Trial design}} \\" ///
				13 "\multicolumn{6}{l}{\textit{Planning and implemententation}} \\" ///
				23 "\hline") ///
		bottom(\bottomrule \end{tabular} \label{tab:survey} ///
		\begin{tablenotes} \small ///
		\item  Data on the institutional constraints rating, duration, and personnel FTE months ///
			were collected from a survey of the researchers involved in the trials ///
			(see text and Appendix Section A.5 for details). Outcome duration is capped at 360 days, which only affects ///
				1 trial in each of the Academic Journal and Nudge Unit samples. *In columns 2 to 4, ///
			the number of survey responses corresponds to the number of Nudge Unit staff members in leadership roles whom we surveyed. /// 
		\end{tablenotes} \end{threeparttable}} \end{table})
*/
}
************************************************
***TABLES 3, A3a,b: AVERAGE TREATMENT EFFECTS***
************************************************
{
	**Academic Journals
	clear all
	eststo clear
	use "./cleaned_data/AcademicJournals.dta"
	
	eststo m1: qui reg treatmenteffect, cl(trialnumber)
	qui sum treatmenteffect, d
	estadd scalar q25 `r(p25)'
	estadd scalar median `r(p50)'
	estadd scalar q75 `r(p75)'
	preserve
		collapse (mean) controlN (sum) treatmentN, by(trialnumber trialsample)
		gen N = controlN+treatmentN
		qui sum N
	restore
	estadd local obs = string(round(`r(sum)'),"%12.0gc")
	qui sum controltakeup
	estadd scalar c `r(mean)'
	qui sum mde, d
	estadd scalar mde `r(p50)'

	eststo n1: qui reg logOR, cl(trialnumber)
	qui sum logOR, d
	estadd scalar q25 `r(p25)'
	estadd scalar median `r(p50)'
	estadd scalar q75 `r(p75)'
	estadd local trials `r(N)'
	preserve
		keep if logOR!=.
		collapse (mean) controlN (sum) treatmentN, by(trialnumber trialsample)
		gen N = controlN+treatmentN
		qui sum N
	restore
	estadd local obs = string(round(`r(sum)'),"%12.0gc")
	qui sum controltakeup if logOR!=.
	estadd scalar c `r(mean)'
	qui sum mdelogOR if logOR!=., d
	estadd scalar mde `r(p50)'

	**Nudge Units
	use "./cleaned_data/NudgeUnits.dta", clear

	eststo m2: qui reg treatmenteffect, cl(trialnumber)
	qui sum treatmenteffect, d
	estadd scalar q25 `r(p25)'
	estadd scalar median `r(p50)'
	estadd scalar q75 `r(p75)'
	preserve
		egen minsplit = min(trialsplit), by(trialnumber trialsample)
		drop if trialsplit!=minsplit
		collapse (mean) controlN (sum) treatmentN, by(trialnumber trialsample)
		gen N = controlN+treatmentN
		qui sum N
	restore
	estadd local obs = string(round(`r(sum)'),"%12.0gc")
	qui sum controltakeup
	estadd scalar c `r(mean)'
	qui sum mde, d
	estadd scalar mde `r(p50)'

	eststo n2: qui reg logOR, cl(trialnumber)
	qui sum logOR, d
	estadd scalar q25 `r(p25)'
	estadd scalar median `r(p50)'
	estadd scalar q75 `r(p75)'
	preserve
		keep if logOR!=.
		egen minsplit = min(trialsplit), by(trialnumber trialsample)
		drop if trialsplit!=minsplit
		collapse (mean) controlN (sum) treatmentN, by(trialnumber trialsample)
		gen N = controlN+treatmentN
		qui sum N
	restore
	estadd local obs = string(round(`r(sum)'),"%12.0gc")
	qui sum controltakeup if logOR!=.
	estadd scalar c `r(mean)'
	qui sum mdelogOR if logOR!=., d
	estadd scalar mde `r(p50)'

	eststo m3: qui reg treatmenteffect if publication==1, cl(trialnumber)
	qui sum treatmenteffect if publication==1, d
	estadd scalar q25 `r(p25)'
	estadd scalar median `r(p50)'
	estadd scalar q75 `r(p75)'
	preserve
		keep if publication==1
		egen minsplit = min(trialsplit), by(trialnumber trialsample)
		drop if trialsplit!=minsplit
		collapse (mean) controlN (sum) treatmentN, by(trialnumber trialsample)
		gen N = controlN+treatmentN
		qui sum N
	restore
	estadd local obs = string(round(`r(sum)'),"%12.0gc")
	qui sum controltakeup if publication==1
	estadd scalar c `r(mean)'
	qui sum mde if publication==1, d
	estadd scalar mde `r(p50)'

	eststo n3: qui reg logOR if publication==1, cl(trialnumber)
	qui sum logOR if publication==1, d
	estadd scalar q25 `r(p25)'
	estadd scalar median `r(p50)'
	estadd scalar q75 `r(p75)'
	preserve
		keep if logOR!=. & publication==1
		egen minsplit = min(trialsplit), by(trialnumber trialsample)
		drop if trialsplit!=minsplit
		collapse (mean) controlN (sum) treatmentN, by(trialnumber trialsample)
		gen N = controlN+treatmentN
		qui sum N
	restore
	estadd local obs = string(round(`r(sum)'),"%12.0gc")
	qui sum controltakeup if logOR!=. & publication==1
	estadd scalar c `r(mean)'
	qui sum mdelogOR if logOR!=. & publication==1, d
	estadd scalar mde `r(p50)'

	eststo m4: qui reg treatmenteffect if OES==0, cl(trialnumber)
	qui sum treatmenteffect if OES==0, d
	estadd scalar q25 `r(p25)'
	estadd scalar median `r(p50)'
	estadd scalar q75 `r(p75)'
	preserve
		keep if OES==0
		egen minsplit = min(trialsplit), by(trialnumber trialsample)
		drop if trialsplit!=minsplit
		collapse (mean) controlN (sum) treatmentN, by(trialnumber trialsample)
		gen N = controlN+treatmentN
		qui sum N
		restore
	estadd local obs = string(round(`r(sum)'),"%12.0gc")
	qui sum controltakeup if OES==0
	estadd scalar c `r(mean)'
	qui sum mde if OES==0, d
	estadd scalar mde `r(p50)'

	eststo m5: qui reg treatmenteffect if OES==1, cl(trialnumber)
	qui sum treatmenteffect if OES==1, d
	estadd scalar q25 `r(p25)'
	estadd scalar median `r(p50)'
	estadd scalar q75 `r(p75)'
	preserve
		keep if OES==1
		egen minsplit = min(trialsplit), by(trialnumber trialsample)
		drop if trialsplit!=minsplit
		collapse (mean) controlN (sum) treatmentN, by(trialnumber trialsample)
		gen N = controlN+treatmentN
		qui sum N
	restore
	estadd local obs = string(round(`r(sum)'),"%12.0gc")
	qui sum controltakeup if OES==1
	estadd scalar c `r(mean)'
	qui sum mde if OES==1, d
	estadd scalar mde `r(p50)'

	eststo n4: qui reg logOR if OES==0, cl(trialnumber)
	qui sum logOR if OES==0, d
	estadd scalar q25 `r(p25)'
	estadd scalar median `r(p50)'
	estadd scalar q75 `r(p75)'
	preserve
		keep if logOR!=. & OES==0
		egen minsplit = min(trialsplit), by(trialnumber trialsample)
		drop if trialsplit!=minsplit
		collapse (mean) controlN (sum) treatmentN, by(trialnumber trialsample)
		gen N = controlN+treatmentN
		qui sum N
	restore
	estadd local obs = string(round(`r(sum)'),"%12.0gc")
	qui sum controltakeup if logOR!=. & OES==0
	estadd scalar c `r(mean)'
	qui sum mdelogOR if logOR!=. & OES==0, d
	estadd scalar mde `r(p50)'

	eststo n5: qui reg logOR if OES==1, cl(trialnumber)
	qui sum logOR if OES==1, d
	estadd scalar q25 `r(p25)'
	estadd scalar median `r(p50)'
	estadd scalar q75 `r(p75)'
	preserve
		keep if logOR!=. & OES==1
		egen minsplit = min(trialsplit), by(trialnumber trialsample)
		drop if trialsplit!=minsplit
		collapse (mean) controlN (sum) treatmentN, by(trialnumber trialsample)
		gen N = controlN+treatmentN
		qui sum N
	restore
	estadd local obs = string(round(`r(sum)'),"%12.0gc")
	qui sum controltakeup if logOR!=. & OES==1
	estadd scalar c `r(mean)'
	qui sum mdelogOR if logOR!=. & OES==1, d
	estadd scalar mde `r(p50)'

	eststo m6: qui reg treatmenteffect if academicaffil==1, cl(trialnumber)
	qui sum treatmenteffect if academicaffil==1, d
	estadd scalar q25 `r(p25)'
	estadd scalar median `r(p50)'
	estadd scalar q75 `r(p75)'
	preserve
		keep if academicaffil==1
		egen minsplit = min(trialsplit), by(trialnumber trialsample)
		drop if trialsplit!=minsplit
		collapse (mean) controlN (sum) treatmentN, by(trialnumber trialsample)
		gen N = controlN+treatmentN
		qui sum N
	restore
	estadd local obs = string(round(`r(sum)'),"%12.0gc")
	qui sum controltakeup if academicaffil==1
	estadd scalar c `r(mean)'
	qui sum mde if academicaffil==1, d
	estadd scalar mde `r(p50)'

	eststo n6: qui reg logOR if academicaffil==1, cl(trialnumber)
	qui sum logOR if academicaffil==1, d
	estadd scalar q25 `r(p25)'
	estadd scalar median `r(p50)'
	estadd scalar q75 `r(p75)'
	preserve
		keep if logOR!=. & academicaffil==1
		egen minsplit = min(trialsplit), by(trialnumber trialsample)
		drop if trialsplit!=minsplit
		collapse (mean) controlN (sum) treatmentN, by(trialnumber trialsample)
		gen N = controlN+treatmentN
	qui sum N
	restore
	estadd local obs = string(round(`r(sum)'),"%12.0gc")
	qui sum controltakeup if logOR!=. & academicaffil==1
	estadd scalar c `r(mean)'
	qui sum mdelogOR if logOR!=. & academicaffil==1, d
	estadd scalar mde `r(p50)'

	esttab m1 m2 m4 m5 m6 using "./output/tables_final/UnweightedSummary_Sep.tex", ///
		se nostar nonotes ///
		mgroups("Academic Journals" "Nudge Units", pattern(1 1 0 0 0) ///
		prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) ///
		mlabels(none) nonumbers posthead("& & All & BIT & OES & Academic-affiliated OES \\ & (1) & (2) & (3) & (4) & (5) \\ \hline") ///
		stat(N N_clust obs c header q25 median q75, fmt(0 0 0 %4.2f 0 %4.2f %4.2f %4.2f) ///
		label("Nudges" "Trials" "Observations" "Average control group take-up (\%)" "\textit{Distribution of treatment effects}" "\hspace{1em}25th percentile" "\hspace{1em}50th percentile" ///
		"\hspace{1em}75th percentile"))  ///
		coeflabels(_cons "Average treatment effect (pp.)") ///
		gaps replace ///
		prehead(\begin{table}[htbp!] \centering \large{\begin{threeparttable} ///
			\caption{Unweighted treatment effects} ///
			\begin{tabular} {l c c c c c} \toprule)  ///
		postfoot(\bottomrule \end{tabular} \label{unweighted} ///
			\begin{tablenotes} \small ///
			\item This table shows the average treatment effect of nudges. Standard errors clustered by trial are shown in parentheses. ///
			pp. refers to percentage point. ///
			\end{tablenotes} \end{threeparttable}} \end{table})

	esttab n1 n2 n4 n5 n6 using "./output/tables_final/UnweightedSummaryLogOR_Sep.tex", ///
		se nostar nonotes ///
		mgroups("Academic Journals" "Nudge Units", pattern(1 1 0 0 0) ///
		prefix(\multicolumn{@span}{c}{) suffix(}) span erepeat(\cmidrule(lr){@span})) ///
		mlabels(none) nonumbers posthead("& & All & BIT & OES & Academic-affiliated OES \\ & (1) & (2) & (3) & (4) & (5) \\ \hline") ///
		stat(N N_clust obs c header q25 median q75, fmt(0 0 0 %4.2f 0 %4.2f %4.2f %4.2f) ///
		label("Nudges" "Trials" "Observations" "Average control group take-up (\%)" "\textit{Distribution of treatment effects}" "\hspace{1em}25th percentile" "\hspace{1em}50th percentile" ///
		"\hspace{1em}75th percentile"))  ///
		coeflabels(_cons "Average treatment effect (log odds ratio)") ///
		gaps replace ///
		prehead(\begin{table}[htbp!] \centering \large{\begin{threeparttable} ///
			\caption{Unweighted treatment effects in log odds ratio} ///
			\begin{tabular} {l c c c c c} \toprule)  ///
		postfoot(\bottomrule \end{tabular} \label{unweightedlogOR} ///
			\begin{tablenotes} \small ///
			\item This table shows the average treatment effect of nudges. Standard errors clustered by trial are shown in parentheses. ///
			\end{tablenotes} \end{threeparttable}} \end{table})

	esttab m3 n3 using "./output/tables_final/UnweightedSummaryPubNU.tex", ///
		se nostar nonotes ///
		mlabels(none) nonumbers posthead("& Percentage points & Log odds ratio \\ & (1) & (2) \\ \hline") ///
		stat(N N_clust obs c header q25 median q75, fmt(0 0 0 %4.2f 0 %4.2f %4.2f %4.2f) ///
		label("Nudges" "Trials" "Observations" "Average control group take-up (\%)" "\textit{Distribution of treatment effects}" "\hspace{1em}25th percentile" "\hspace{1em}50th percentile" ///
		"\hspace{1em}75th percentile"))  ///
		coeflabels(_cons "Average treatment effect") ///
		gaps replace ///
		prehead(\begin{table}[htbp!] \centering \large{\begin{threeparttable} ///
			\caption{Unweighted treatment effects for Published Nudge Unit trials} ///
			\begin{tabular} {l c c} \toprule)  ///
		postfoot(\bottomrule \end{tabular} \label{unweightedpubNU} ///
			\begin{tablenotes} \small ///
			\item This table shows the average treatment effect of nudges. Standard errors clustered by trial are shown in parentheses. ///
			\end{tablenotes} \end{threeparttable}} \end{table})
}
**************************************************
***TABLE 4, A6a,b, A7: PREDICTING NUDGE EFFECTS***
**************************************************
/*
NOTE: The responses to the researcher survey (i.e., variables survey_*)
have been redacted for confidentiality. As a result,
the code for Table 4 will not run on this redacted data file.
*/
{
/*
	eststo clear
	clear
	use "./cleaned_data/NudgeUnits.dta"
	gen AJ=0
	append using "./cleaned_data/AcademicJournals.dta", force
	replace AJ = 1 if missing(AJ)
	label var AJ "Acad. Jour."

	**Clean labels and generate one-time variables for regression
	gen publishedNU=(AJ==0 & publication==1)
	label var publishedNU "Published Nudge Unit trial"

	gen controltakeupmissing=missing(controltakeup)
	qui count if controltakeupmissing==1
	local missingCtrt=r(N)
	qui count if controltakeupmissing==1 & mostsig==1
	local missingCtr=r(N)
	qui sum controltakeup
	replace controltakeup=r(mean) if missing(controltakeup)
	gen controltakeupsq=controltakeup*controltakeup
	label var controltakeup "\hspace{1em}Control take-up (\%)"
	label var controltakeupsq "\hspace{1em}Control take-up$^2$"
	label var mde "MDE"
	replace academicaffil=1 if AJ==1
	label var academicaffil "Academic involved"

	gen 	policy=1 if policyarea=="Revenue collection and debt repayment"
	replace policy=2 if policyarea=="Take-up of benefits and programs"
	replace policy=3 if policyarea=="Workforce and education"
	replace policy=4 if policyarea=="Health"
	replace policy=5 if policyarea=="Registration and regulation compliance"
	replace policy=6 if policyarea=="Community engagement"
	replace policy=7 if policyarea=="Environment"
	replace policy=8 if policyarea=="Consumer behavior"

	label define policy 1 "\hspace{2em}Revenue \& debt" 2 "\hspace{2em}Benefits \& programs" 3 "\hspace{2em}Workforce \& education" 4 "\hspace{2em}Health" 5 "\hspace{2em}Registrations \& regulation compliance" 6 "\hspace{2em}Community engagement" 7 "\hspace{2em}Environment" 8 "\hspace{2em}Consumer behavior"
	label values policy policy

	label define controlreceivescomm 0 "\hspace{2em}No communication" 1 "\hspace{2em}Some communication", replace
	label values controlreceivescomm controlreceivescomm
	
	gen recent=(year>2014) if AJ==1
	replace recent=(year>=2017) if AJ==0
	
	local medlist medium_email medium_physicalletter medium_postcard medium_website medium_inperson medium_other
	local medlabel `" "\hspace{2em}Email" "\hspace{2em}Physical letter" "\hspace{2em}Postcard" "\hspace{2em}Website" "\hspace{2em}In person" "\hspace{2em}Other" "'
	local n : word count `medlist'
	forvalues i=1/`n' {
		local a: word `i' of `medlist'
		local b: word `i' of `medlabel'
		label var `a' "`b'"
	}
	
	local mechlist mech_simplification mech_personalmotivation mech_planning mech_socialcues mech_framing mech_choicedesign
	local mechlabel `" "\hspace{2em}Simplification \& information" "\hspace{2em}Personal motivation" "\hspace{2em}Reminders \& planning prompts" "\hspace{2em}Social cues" "\hspace{2em}Framing \& formatting" "\hspace{2em}Choice design" "'
	local n : word count `mechlist'
	forvalues i=1/`n' {
		local a: word `i' of `mechlist'
		local b: word `i' of `mechlabel'
		label var `a' "`b'"
	}
	
	gen outcometfmissing = (outcomedurationdays==.)
	rename outcomedurationdays outcometf
	replace outcometf = 0 if missing(outcometf)
	
	gen survey_duration = survey_durationplanning + survey_durationdata
	local varlist survey_constraints survey_durationtotal survey_duration survey_durationplanning survey_durationdata survey_durationwriting survey_FTE
	foreach var in `varlist' {
		gen `var'missing = (`var'==.)
		replace `var' = 0 if missing(`var')
	}
	
	**Table 4
	preserve
		local loglist outcometf survey_duration survey_FTE 
		foreach var in `loglist' {
			replace `var'=ln(`var') if `var'!=0
			replace `var'=-1 if `var'==0
		}
		
		label var survey_duration "\hspace{1em}Log(planning \& implementation months)"
		label var survey_FTE "\hspace{1em}Log(personnel FTE months)"
		label var survey_constraints "\hspace{1em}Ideal nudge implemented rating (1-5)"
		label var outcometf "\hspace{1em}Log(outcome time-frame days)"

		eststo a1: reg treatmenteffect 1.AJ, cl(trialnumber)
		eststo a2: reg treatmenteffect 1.AJ b1.policy `medlist' b0.controlreceivescomm `mechlist' controltakeup controltakeupsq outcometf controltakeupmissing outcometfmissing, cl(trialnumber)
		eststo a3: reg treatmenteffect i.AJ##c.mde, cl(trialnumber)
		eststo a4: reg treatmenteffect i.AJ##c.mde b1.policy `medlist' b0.controlreceivescomm `mechlist' controltakeup controltakeupsq outcometf controltakeupmissing outcometfmissing, cl(trialnumber)
		eststo a5: reg treatmenteffect 1.AJ if academicaffil==1, cl(trialnumber)
		eststo a6: reg treatmenteffect 1.AJ survey_constraints survey_FTE survey_duration survey_FTEmissing survey_durationmissing survey_constraintsmissing outcometfmissing if academicaffil==1, cl(trialnumber)
		eststo a7: reg treatmenteffect i.AJ##c.mde survey_constraints survey_FTE survey_duration survey_FTEmissing survey_durationmissing survey_constraintsmissing outcometfmissing if academicaffil==1, cl(trialnumber)

		esttab a* using "./output/tables_final/RegressionDecomp.tex", replace ///
				b(%4.3f) se nostar nogaps label varwidth(40) nonumbers ///
				order(_cons 1.AJ mde 1.AJ#c.mde) ///
				drop(0.AJ 0.AJ#c.mde 1.policy 0.controlreceivescomm survey_FTEmissing survey_durationmissing survey_constraintsmissing controltakeupmissing outcometfmissing ) ///
				coeflabels(1.AJ "\hspace{1em}Academic Journals" mde "\hspace{1em}Minimum detectable effect (MDE)" 1.AJ#c.mde "\hspace{1em}Academic Journals$\times\text{MDE}$") ///
				mlabels("(1)" "(2)" "(3)" "(4)" "(5)" "(6)" "(7)", lhs("Dep. Var.: Treatment effect (pp.)")) ///
				stat(N N_clust r2, fmt(0 0 %4.2f) label("Nudges" "Trials" "R-squared")) ///
				refcat(1.AJ "\textit{\textbf{Omitted group: Nudge Units}}" ///
					mde "\textit{\textbf{Publication bias controls (Egger's test)}}" ///
					2.policy "\textit{\textbf{Nudge categories}} \\ \hspace{1em}\textit{Policy area}" ///
					medium_email "\hspace{1em}\textit{Medium of communication}" ///
					1.controlreceivescomm "\hspace{1em}\textit{Control group receives:}" ///
					mech_simplification "\hspace{1em}\textit{Mechanism}" ///
					controltakeup "\textit{\textbf{Trial features}}", nolabel) ///
				prehead(\begin{table}[htbp!] \scriptsize{\centering \begin{threeparttable} ///	
					\caption{Predicting nudge effect sizes} ///
					\begin{tabular} {l c c c c c c c} \toprule ///
					& \multicolumn{4}{c}{Full sample} & \multicolumn{3}{c}{Academic-affiliated only} \\ \cmidrule(lr){2-5} \cmidrule(lr){6-8}) ///
				postfoot(\bottomrule \end{tabular} \label{tab:decompreg} ///
					\begin{tablenotes} \scriptsize ///
					\item This table shows OLS estimates with standard errors clustered by trial in parentheses. ///
						The MDE (minimum detectable effect) is calculated in pp. at power 0.8. ///
						Observations with missing data for ///
						outcome time-frame, control take-up result, trial duration, institutional constraints rating, ///
						or personnel FTE months are included with separate dummies. ///				
					\end{tablenotes} \end{threeparttable}} \end{table})
	restore
	
	**Tables A6a,b labels
	label define policy 1 "\hspace{1em}Revenue \& debt" 2 "\hspace{1em}Benefits \& programs" 3 "\hspace{1em}Workforce \& education" 4 "\hspace{1em}Health" 5 "\hspace{1em}Registrations \& regulation compliance" 6 "\hspace{1em}Community engagement" 7 "\hspace{1em}Environment" 8 "\hspace{1em}Consumer behavior", replace
	label values policy policy

	label define controlreceivescomm 0 "\hspace{1em}No communication" 1 "\hspace{1em}Some communication", replace
	label values controlreceivescomm controlreceivescomm
	
	local medlist medium_email medium_physicalletter medium_postcard medium_website medium_inperson
	local medlabel `" "\hspace{1em}Email" "\hspace{1em}Physical letter" "\hspace{1em}Postcard" "\hspace{1em}Website" "\hspace{1em}In person" "\hspace{1em}Other" "'
	local n : word count `medlist'
	forvalues i=1/`n' {
		local a: word `i' of `medlist'
		local b: word `i' of `medlabel'
		label var `a' "`b'"
	}
	
	local mechlist mech_simplification mech_personalmotivation mech_planning mech_socialcues mech_framing mech_choicedesign
	local mechlabel `" "\hspace{1em}Simplification \& information" "\hspace{1em}Personal motivation" "\hspace{1em}Reminders \& planning prompts" "\hspace{1em}Social cues" "\hspace{1em}Framing \& formatting" "\hspace{1em}Choice design" "'
	local n : word count `mechlist'
	forvalues i=1/`n' {
		local a: word `i' of `mechlist'
		local b: word `i' of `mechlabel'
		label var `a' "`b'"
	}

	**Table A6a
	eststo clear
	preserve
		keep if AJ==1
		collapse (mean) controlN (sum) treatmentN, by(trialnumber trialsample)
		gen N = controlN+treatmentN
		qui sum N
	restore
	local obs = round(`r(sum)')
	preserve
		keep if AJ==1
		qui sum controltakeup
		local cmean=`r(mean)'
		
		replace outcometf=ln(outcometf) if outcometf!=0
		replace outcometf=-1 if outcometf==0
		
		eststo r1: qui reg treatmenteffect mde, cluster(trialnumber)
		estadd scalar obs `obs'
		estadd scalar c `cmean'
		
		eststo r2: qui reg treatmenteffect controltakeup controltakeupsq outcometf outcometfmissing, cluster(trialnumber)
		estadd scalar obs `obs'
		estadd scalar c `cmean'

		eststo r3: qui reg treatmenteffect b0.recent, cluster(trialnumber)
		estadd scalar obs `obs'
		estadd scalar c `cmean'

		eststo r4: qui reg treatmenteffect b1.policy, cluster(trialnumber)
		estadd scalar obs `obs'
		estadd scalar c `cmean'

		eststo r5: qui reg treatmenteffect `medlist', cluster(trialnumber)
		estadd scalar obs `obs'
		estadd scalar c `cmean'

		eststo r6: qui reg treatmenteffect b0.controlreceivescomm, cluster(trialnumber)
		estadd scalar obs `obs'
		estadd scalar c `cmean'
		
		eststo r7: qui reg treatmenteffect `mechlist', cluster(trialnumber)
		estadd scalar obs `obs'
		estadd scalar c `cmean'
		
		eststo r8: qui reg treatmenteffect controltakeup controltakeupsq outcometf outcometfmissing b1.policy b0.controlreceivescomm `medlist' `mechlist' b0.recent mde, cluster(trialnumber)
		estadd scalar obs `obs'
		estadd scalar c `cmean'

		eststo l: lasso linear treatmenteffect controltakeup controltakeupsq outcometf outcometfmissing b1.policy b0.controlreceivescomm `medlist' `mechlist' b0.recent mde, rseed(1)
		estadd scalar obs `obs'
		estadd scalar c `cmean'
		qui distinct trialnumber
		estadd scalar N_clust `r(ndistinct)'

		esttab r* l using "./output/tables_final/HMB_Heterogeneity.tex", replace ///
		b(%4.3f) se nostar nogaps label varwidth(40) drop(outcometfmissing 1.policy 0.controlreceivescomm 0.recent) ///
		mlabels("OLS" "OLS" "OLS" "OLS" "OLS" "OLS" "OLS" "OLS" "Lasso") ///
		nonumbers posthead("Dep. Var.: Treatment effect (pp.) & (1) & (2) & (3) & (4) & (5) & (6) & (7) & (8) & (9) \\ \hline") ///
		stat(N N_clust obs r2 c, fmt(0 0 %16.0gc %4.2f %4.2f) label("Nudges" "Trials" "Observations" "R-squared" "Avg. control take-up"))  ///
		refcat(1.recent "\textit{Date}" 2.policy "\textit{Policy area}" medium_email "\textit{Medium of communication}" 1.controlreceivescomm "\textit{Control group receives:}" mech_simplification "\textit{Mechanism}", nolabel) ///
		coef(1.recent "\hspace{1em}Recent (published after 2014)" mde "Minimum detectable effect (pp.)" controltakeup "Control take-up \%" controltakeupsq "Control take-up \%$^2$" outcometf "Log(outcome time-frame days)") ///
		prehead(\begin{table}[htbp!] \scriptsize{ \centering \begin{threeparttable} ///
			\caption{Heterogeneity in effects by nudge categories: Academic Journals} ///
			\begin{tabular} {l c c c c c c c c c} \toprule)  ///
		postfoot(\bottomrule \end{tabular} \label{heterogeneity} ///
			\begin{tablenotes} \footnotesize ///
			\item Standard errors clustered by trial are shown in parentheses. ///
			The minimum detectable effect (MDE) is calculated in pp. at power 0.8. ///
			The penalty parameter in the linear lasso model is selected with cross-validation. ///
			\end{tablenotes} \end{threeparttable}} \end{table})
	restore
	
	**Table A6b
	eststo clear
	preserve
		keep if AJ==0
		egen minsplit = min(trialsplit), by(trialnumber trialsample)
		drop if trialsplit!=minsplit
		collapse (mean) controlN (sum) treatmentN, by(trialnumber trialsample)
		gen N = controlN+treatmentN
		qui sum N
	restore
	local obs = round(`r(sum)')
	preserve
		keep if AJ==0
		qui sum controltakeup if controltakeupmissing==0
		local cmean = `r(mean)'
		replace controltakeup=`cmean' if controltakeupmissing==1
		replace controltakeupsq=controltakeup*controltakeup if controltakeupmissing==1
		
		replace outcometf=ln(outcometf) if outcometf!=0
		replace outcometf=-1 if outcometf==0
		
		eststo r1: qui reg treatmenteffect mde, cluster(trialnumber)
		estadd scalar obs `obs'
		estadd scalar c `cmean'
		
		eststo r2: qui reg treatmenteffect controltakeup controltakeupsq outcometf outcometfmissing controltakeupmissing, cluster(trialnumber)
		estadd scalar obs `obs'
		estadd scalar c `cmean'

		eststo r3: qui reg treatmenteffect b0.recent, cluster(trialnumber)
		estadd scalar obs `obs'
		estadd scalar c `cmean'

		eststo r4: qui reg treatmenteffect b1.policy, cluster(trialnumber)
		estadd scalar obs `obs'
		estadd scalar c `cmean'

		eststo r5: qui reg treatmenteffect `medlist', cluster(trialnumber)
		estadd scalar obs `obs'
		estadd scalar c `cmean'

		eststo r6: qui reg treatmenteffect b0.controlreceivescomm, cluster(trialnumber)
		estadd scalar obs `obs'
		estadd scalar c `cmean'
		
		eststo r7: qui reg treatmenteffect `mechlist', cluster(trialnumber)
		estadd scalar obs `obs'
		estadd scalar c `cmean'
		
		eststo r8: qui reg treatmenteffect controltakeup controltakeupsq outcometf outcometfmissing b1.policy b0.controlreceivescomm `medlist' `mechlist' b0.recent mde controltakeupmissing, cluster(trialnumber)
		estadd scalar obs `obs'
		estadd scalar c `cmean'

		eststo l: lasso linear treatmenteffect controltakeup controltakeupsq outcometf outcometfmissing b1.policy b0.controlreceivescomm `medlist' `mechlist' b0.recent mde controltakeupmissing, rseed(2)
		estadd scalar obs `obs'
		estadd scalar c `cmean'
		qui distinct trialnumber
		estadd scalar N_clust `r(ndistinct)'
		
		esttab r* l using "./output/tables_final/OB_Heterogeneity.tex", replace ///
			b(%4.3f) se nostar nogaps label varwidth(40) drop(outcometfmissing 1.policy 0.controlreceivescomm 0.recent controltakeupmissing) ///
			mlabels("OLS" "OLS" "OLS" "OLS" "OLS" "OLS" "OLS" "OLS" "Lasso") ///
			nonumbers posthead("Dep. Var.: Treatment effect (pp.) & (1) & (2) & (3) & (4) & (5) & (6) & (7) & (8) & (9) \\ \hline") ///
			stat(N N_clust obs r2 c, fmt(0 0 %16.0gc %4.2f %4.2f) label("Nudges" "Trials" "Observations" "R-squared" "Avg. control take-up"))  ///
			refcat(1.recent "\textit{Date}" 2.policy "\textit{Policy area}" medium_email "\textit{Medium of communication}" 1.controlreceivescomm "\textit{Control group receives:}" mech_simplification "\textit{Mechanism}", nolabel) ///
			coef(1.recent "\hspace{1em}Recent (2017-)" mde "Minimum detectable effect (pp.)" controltakeup "Control take-up \%" controltakeupsq "Control take-up \%$^2$" outcometf "Log(outcome time-frame days)") ///
			prehead(\begin{table}[htbp!] \scriptsize{ \centering \begin{threeparttable} ///
				\caption{Heterogeneity in effects by nudge categories: Nudge Units} ///
				\begin{tabular} {l c c c c c c c c c} \toprule)  ///
			postfoot(\bottomrule \end{tabular} \label{heterogeneity} ///
				\begin{tablenotes} \footnotesize ///
			\item Standard errors clustered by trial are shown in parentheses. ///
					The minimum detectable effect (MDE) is calculated in pp. at power 0.8. ///
					The penalty parameter in the linear lasso model is selected with cross-validation. ///
					The `missingCtrt' nudges (`missingCtr' trials) missing control take-up data ///
					are dummied out when including control take-up in the regression. ///
				\end{tablenotes} \end{threeparttable}} \end{table})
	restore
		
	**Table A7
	local medlist medium_email medium_physicalletter medium_postcard medium_website medium_inperson medium_other
	eststo clear
	logit AJ b1.policy `medlist' b0.controlreceivescomm `mechlist' controltakeup controltakeupsq outcometf controltakeupmissing outcometfmissing if trialnumber!=46
	predict prob
	replace prob=1 if trialnumber==46 // perfectly predicted
	gen Pweight=1/(1-prob) if AJ==0
	replace Pweight=1/prob if AJ==1
	gen mdeinv=1/mde
	gen InvVar=1/SE^2
	gen mdePweight=mdeinv*Pweight

	eststo s1: qui reg treatmenteffect 1.AJ##c.SE [aweight=InvVar], cl(trialnumber)
	estadd local invvar "$\checkmark$"
	estadd local precision ""
	estadd local controls ""
	eststo s2: qui reg treatmenteffect 1.AJ [aweight=mdeinv], cl(trialnumber)
	estadd local precision "$\checkmark$"
	estadd local controls ""
	eststo s3: qui reg treatmenteffect 1.AJ [aweight=Pweight], cl(trialnumber)
	estadd local precision ""
	estadd local controls "$\checkmark$"
	eststo s4: qui reg treatmenteffect 1.AJ [aweight=mdePweight], cl(trialnumber)
	estadd local precision "$\checkmark$"
	estadd local controls "$\checkmark$"

	esttab s* using "./output/tables_final/OB_HMB_regression_wgt.tex", replace ///
		b(%4.3f) se nostar nogaps label varwidth(40) ///
		keep(1.AJ SE 1.AJ#c.SE _cons) ///
		mlabels("(1) Egger's test" "(2)" "(3)" "(4)", lhs("Dep. Var.: Treatment effect (pp.)")) ///
		nonumbers ///
		coeflabels(1.AJ "Academic Journals" SE "Standard error (SE)" 1.AJ#c.SE "Academic Journals$\times\text{SE}$" _cons "Constant") ///
		stat(N N_clust r2 invvar precision controls, fmt(0 0 %4.3f)  ///
		label("Nudges" "Trials" "R-squared" "Weighted by 1/SE$^2$" "Weighted by 1/MDE" "Weighted by P-score from nudge categories"))  ///
		prehead(\begin{table}[htbp!] \centering \large{\begin{threeparttable} ///	
			\caption{Weighted decomposition between Nudge Units and Academic Journals} ///
			\begin{tabular} {l c c c c} \toprule)  ///
		postfoot(\bottomrule \end{tabular} \label{} ///
			\begin{tablenotes} \small ///
			\item Standard errors clustered by trial are shown in parentheses. ///
			The coefficient on Academic Journals sample is the estimated average difference in percentage point (pp.) ///
			treatment effects between the Academic Journals and Nudge Units samples. ///
			MDE (minimum detectable effect) is calculated in pp. at power 0.8. ///
			P-score is the propensity score of being in the Academic Journals sample ///
			using predicted probabilities from a logit ///
			regression that includes the same nudge category controls as in ///
			Column 2 of Table \ref{tab:decompreg}. ///
			\end{tablenotes} \end{threeparttable}} \end{table})
*/
}
****************************************************
***FIGURES A8a,b: COLLABORATION WITH SAME PARTNER***
****************************************************
{
	clear all
	use "./cleaned_data/NudgeUnits.dta"
	
	preserve
		tostring partnerid, gen(partner)
		replace partner="" if partner=="."
		replace partner=collaborateddepartment if OES==1
		
		bysort trialnumber: gen n=_n
		drop if n!=1
		
		sort OES partner trialnumber
		bysort OES partner: gen partnerN=_N if partner!=""
		bysort OES partner: gen partnern=_n if partner!=""
		egen partnerID=group(OES partner) if partner!=""
			
		gen odd=(mod(partnerN,2)==1) if partner!=""
		gen median=ceil(partnerN/2) if partner!=""
		gen earlywithin=(partnern<=median) if partner!=""
		replace earlywithin=. if partnern==median & odd==1 // exclude median if partnerN is odd & drops those with partnerN==1
		
		keep trialnumber partnerID partner partnern partnerN earlywithin
		tempfile x
		save `x', replace
	restore 

	merge m:1 trialnumber using `x'
	drop _merge
	
	cumul treatmenteffect if earlywithin==0, gen(cumulearly)
	cumul treatmenteffect if earlywithin==1, gen(cumullate)
		
	qui count if earlywithin==0 
	local latenudges=r(N)
	qui distinct trialnumber if earlywithin==0
	local latetrials=r(ndistinct)
	qui count if earlywithin==1
	local earlynudges=r(N)
	qui distinct trialnumber if earlywithin==1
	local earlytrials=r(ndistinct)
	twoway (line cumulearly treatmenteffect if treatmenteffect>=-5 & treatmenteffect<=10, sort(cumulearly) lcolor(navy%50) lpattern(longdash) lwidth(thick)) ///
		(line cumullate treatmenteffect if treatmenteffect>=-5 & treatmenteffect<=10, sort(cumullate) lcolor(blue%50)), ///
		graphregion(color(white)) bgcolor(white) ytitle("CDF") xtitle("Treatment effect (pp.)") ///
		legend(order(1 "Early collaborations (`earlytrials' trials, `earlynudges' nudges)" 2 "Later collaborations (`latetrials' trials, `latenudges' nudges)") col(1)) 
	graph export "./output/figures_final/earlylatewithin_te.pdf", replace
	drop cumul*

	qui binscatter partnerN treatmenteffect if partnern==1 & mostsig==1 & (maxtdefinc<=maxt | maxtdefinc==.), nquantiles(10) genxq(decilete)
	egen partnerNtedec=mean(partnerN) if decilete!=., by(decilete)
	bysort decilete: gen nte=_n if decilete!=.
	egen minte_widec=min(treatmenteffect), by(decilete)
	egen maxte_widec=max(treatmenteffect), by(decilete)
	tostring minte_widec, replace format("%4.1f") force
	tostring maxte_widec, replace format("%4.1f") force
	gen rangete_widec=minte_widec+" - "+maxte_widec+"pp."

	twoway (scatter partnerNtedec decilete if nte==1, ///
		mlabel(rangete_widec) mlabpos(12) mlabsize(vsmall)) ///
		(lfit partnerNtedec decilete if nte==1), ///
		graphregion(color(white)) bgcolor(white) ///
		ytitle("Average number of total collaborations") ///
		xtitle("Decile of treatment effect in first collaboration") ///
		legend(off) ///
		yscale(range(0(1)4)) ytick(0(1)4) ylabel(0(1)4) ///
		xscale(range(0(1)11)) xtick(1(1)10) xlabel(1(1)10)
	graph export "./output/figures_final/partnerN_te_decile.pdf", replace
}
*****************************
***TABLE A4a,b: ROBUSTNESS***
*****************************
{
	**Table A4a
	eststo clear
	clear all
	use "./cleaned_data/NudgeUnits.dta"
	gen OB = 1
	keep OB treatmenteffect SE t
	append using "./cleaned_data/AcademicJournals.dta", keep(treatmenteffect SE t)
	replace OB = 0 if missing(OB)

	gen significant = (abs(t)>=1.96)
	gen positive = (treatmenteffect>=0)
	gen category 	 = 1 if significant==1 & positive==1
	replace category = 2 if significant==0 & positive==1
	replace category = 3 if significant==0 & positive==0
	replace category = 4 if significant==1 & positive==0

	label var OB "Academic Journals indicator"
	label define OB 0 "Academic Journals" 1 "Nudge Units"
	label values OB OB

	label var category "Treatment effect category"
	label define category 1 "Significant \& positive" 2 "Insignificant \& positive" 3 "Insignificant \& negative" 4 "Significant \& negative"
	label values category category

	mat sum = J(5,5,.)
	qui tab category OB, matcell(freq)

	forvalues j=0/1 {
		forvalues i=1/4 {
			mat sum[1+`i',2+`j'*2]=freq[`i',1+`j']
			qui count if OB == `j'
			mat sum[1+`i',3+`j'*2]=round(100*sum[1+`i',2+`j'*2]/`r(N)',0.01)
			
		}
	}

	mata: sum=strofreal(st_matrix("sum"))

	mata
	sum[1,1]=""
	sum[1,2]="Nudges"
	sum[1,3]="Freq. (\%)"
	sum[1,4]="Nudges"
	sum[1,5]="Freq. (\%)"
	end
	qui tab category, gen(category)
	forvalues i=1/4 {
		local label : var label category`i'
		local name = substr(`"`label'"',11,100)
		mata: sum[1+`i',1] = "`name'"
	}

	qui count if OB == 1
	local OBcount = `r(N)'
	qui count if OB == 0
	local HMBcount = `r(N)'

	mmat2tex sum using "./output/tables_final/PosNegInSig.tex", ///
		replace ///
		preheader(\begin{table}[htbp!] \centering \large{\begin{threeparttable} ///
		\caption{Categorization of treatment effects} ///
		\begin{tabular} {l c c c c} \toprule ///
		&\multicolumn{2}{c}{Academic Journals}&\multicolumn{2}{c}{Nudge Units}\\\cmidrule(lr){2-3}\cmidrule(lr){4-5}) ///
		postheader(\hline) ///
		bottom( \hline Total & `HMBcount' & 100 & `OBcount' & 100 \\ ///
		\bottomrule \end{tabular} \label{posneginsig} ///
		\begin{tablenotes} \small ///
		\item Significance is determined at the 95\% level. ///
		\end{tablenotes} \end{threeparttable}} \end{table})
	
	
	**Table A4b
	clear all
	
	use "./cleaned_data/AcademicJournals.dta"
	gen citweight=asinh(citations)

	eststo u1: qui reg treatmenteffect, cl(trialnumber)
	preserve
		collapse (mean) controlN (sum) treatmentN, by(trialnumber trialsample)
		gen N = controlN+treatmentN
		qui sum N
	restore
	estadd scalar obs = round(`r(sum)')

	eststo ca1: qui reg treatmenteffect [aweight=citations], cl(trialnumber)
	eststo cb1: qui reg treatmenteffect [aweight=citweight], cl(trialnumber)

	eststo prt1: qui reg treatmenteffect if avgpriorityrank50==1, cl(trialnumber)

	gen lowcost=(medium_email==1|controlreceivescomm==1)
	eststo lc1: qui reg treatmenteffect if lowcost==1, cl(trialnumber)
	
	use "./cleaned_data/NudgeUnits.dta", clear
	count if citations==0
	local nocittrt `r(N)'
	preserve
		bysort trialnumber: gen n=_n
		drop if n!=1
		count if citations==0
	restore
	local nocittr `r(N)'
	replace citations=1 if citations==0
	gen citweight=asinh(citations)

	eststo u3: qui reg treatmenteffect, cl(trialnumber)
	preserve
		egen minsplit = min(trialsplit), by(trialnumber trialsample)
		drop if trialsplit!=minsplit
		collapse (mean) controlN (sum) treatmentN, by(trialnumber trialsample)
		gen N = controlN+treatmentN
		qui sum N
	restore
	estadd scalar obs = round(`r(sum)')

	eststo ca3: qui reg treatmenteffect [aweight=citations], cl(trialnumber)
	eststo cb3: qui reg treatmenteffect [aweight=citweight], cl(trialnumber)

	eststo prt3: qui reg treatmenteffect if avgpriorityrank50==1, cl(trialnumber)

	gen lowcost=(medium_email==1|controlreceivescomm==1)
	eststo lc3: qui reg treatmenteffect if lowcost==1, cl(trialnumber)

	eststo u5: qui reg treatmenteffect if publication==1, cl(trialnumber)
	preserve
		drop if publication!=1
		egen minsplit = min(trialsplit), by(trialnumber trialsample)
		drop if trialsplit!=minsplit
		collapse (mean) controlN (sum) treatmentN, by(trialnumber trialsample)
		gen N = controlN+treatmentN
		qui sum N
	restore
	estadd scalar obs = round(`r(sum)')

	eststo ca5: qui reg treatmenteffect if publication==1 [aweight=citations], cl(trialnumber)
	eststo cb5: qui reg treatmenteffect if publication==1 [aweight=citweight], cl(trialnumber)
	
	eststo prt5: qui reg treatmenteffect if avgpriorityrank50pub==1 & publication==1, cl(trialnumber)
	eststo lc5: qui reg treatmenteffect if lowcost==1 & publication==1, cl(trialnumber)

	*Default rows
	use "./cleaned_data/AcademicJournals_InclDefaults.dta", clear

	eststo d1: qui reg treatmenteffect, cl(trialnumber)
	preserve
		collapse (mean) controlN (sum) treatmentN, by(trialnumber trialsample)
		gen N = controlN+treatmentN
		qui sum N
	restore
	estadd scalar obs = round(`r(sum)')

	use "./cleaned_data/NudgeUnits_InclDefaults.dta", clear

	eststo d3: qui reg treatmenteffect, cl(trialnumber)
	preserve
		egen minsplit = min(trialsplit), by(trialnumber trialsample)
		drop if trialsplit!=minsplit
		collapse (mean) controlN (sum) treatmentN, by(trialnumber trialsample)
		gen N = controlN+treatmentN
		qui sum N
	restore
	estadd scalar obs = round(`r(sum)')

	eststo d5: qui reg treatmenteffect if publication==1, cl(trialnumber)
	preserve
		drop if publication!=1
		egen minsplit = min(trialsplit), by(trialnumber trialsample)
		drop if trialsplit!=minsplit
		collapse (mean) controlN (sum) treatmentN, by(trialnumber trialsample)
		gen N = controlN+treatmentN
		qui sum N
	restore
	estadd scalar obs = round(`r(sum)')

	local lastrow=17
	mat results=J(`lastrow',4,.)

	esttab u*, nostar se stat(N N_clust obs, fmt(0 0 %16.0gc))
	forvalues i=1/3 {
		mat results[1,`i'+1]=r(coefs)[1,2*`i'-1]
		mat results[2,`i'+1]=r(coefs)[1,2*`i']
	}
	forvalues i=1/3 {
		mat results[`lastrow'-3+`i',2]=r(stats)[`i',1...]
	}

	esttab d*, nostar se
	forvalues i=1/3 {
		mat results[4,`i'+1]=r(coefs)[1,2*`i'-1]
		mat results[5,`i'+1]=r(coefs)[1,2*`i']
	}
	
	esttab prt*, nostar se
	forvalues i=1/3 {
		mat results[6,`i'+1]=r(coefs)[1,2*`i'-1]
		mat results[7,`i'+1]=r(coefs)[1,2*`i']
	}

	esttab lc*, nostar se
	forvalues i=1/3 {
		mat results[8,`i'+1]=r(coefs)[1,2*`i'-1]
		mat results[9,`i'+1]=r(coefs)[1,2*`i']
	}

	esttab ca*, nostar se
	forvalues i=1/3 {
		mat results[11,`i'+1]=r(coefs)[1,2*`i'-1]
		mat results[12,`i'+1]=r(coefs)[1,2*`i']
	}
	esttab cb*, nostar se
	forvalues i=1/3 {
		mat results[13,`i'+1]=r(coefs)[1,2*`i'-1]
		mat results[14,`i'+1]=r(coefs)[1,2*`i']
	}


	mata
	results=strofreal(st_matrix("results"))
	results[1,1]="Average treatment effect (pp.)"
	results[3,1]="\textit{\textbf{Panel A.} ATE including:}"
	results[4,1]="\hspace{1em}Defaults"
	results[6,1]="\hspace{1em}Most policy relevant"
	results[8,1]="\hspace{1em}Low cost interventions"
	results[10,1]="\textit{\textbf{Panel B.} ATE weighted by:}"
	results[11,1]="\hspace{1em}Citations"
	results[13,1]="\hspace{1em}asinh(citations)"
	results[`lastrow'-2,1]="Nudges"
	results[`lastrow'-1,1]="Trials"
	results[`lastrow',1]="Observations"
	end

	forvalues j=2/4 {
		
		local x = string(results[`lastrow',`j'],"%12.0gc")
		mata: results[`lastrow',`j'] = "`x'"
		
		foreach i in 1 4 6 8 11 13 {
			local x = string(results[`i',`j'],"%4.2f")
			mata: results[`i',`j'] = "`x'"
		}
		
		foreach i in 2 5 7 9 12 14 {
			local x = "("+string(results[`i',`j'],"%4.2f")+")"
			mata: results[`i',`j'] = "`x'"
		}
		
		
		foreach i in 3 10 {
			mata:results[`i',`j'] = ""
		}
	}

	foreach j in 3 {
		forvalues i=11(2)13 {
			mata: results[`i',`j']="--"
		}
		forvalues i=12(2)14 {
			mata: results[`i',`j']=""
		}
	}

	foreach j in 2 {
		foreach i in 8 {
			mata: results[`i',`j']="--"
		}
		foreach i in 9 {
			mata: results[`i',`j']=""
		}
	}

	foreach i in 2 5 7 9 12 14 {
		mata: results[`i',1]=""
	}

	local hline=`lastrow'-2

	mmat2tex results using "./output/tables_final/Robustness.tex", ///
		replace fmt("%4.2f") ///
		preheader(\begin{table}[htbp!] \centering \large{\begin{threeparttable} ///
		\caption{Robustness checks} \begin{tabular} {l c c c} \toprule ///
			& Academic Journals & Nudge Units & Published Nudge Units ///
		\\\cmidrule(lr){2-2}\cmidrule(lr){3-3}\cmidrule(lr){4-4} ///
		& (1) & (2) & (3) \\ \hline) ///
		insertendrow(`hline' "\hline") ///
		bottom(\bottomrule \end{tabular} \label{tab:robustness} ///
		\begin{tablenotes} \small ///
		\item This table shows the average treatment effects ///
		including default nudges, only the outcomes in the top half of policy relevance, ///
		or only nudges with low cost interventions, and ///
		weighting treatment effects by citations. ///
		Standard errors clustered by trial are shown in parentheses. ///
		The Nudge Units sample has 2 nudges (from 1 trial) that use defaults on 1.3 million participants ///
		and have treatment effects in pp. (standard errors) of ///
		9.4 (0.15) and 11.2 (0.15). ///
		The Academic Journals sample has 3 nudges (from 3 trials) that use defaults on 548 participants ///
		and have treatment effects in pp. (standard errors) of ///
		-0.1 (3.6), 3.9 (7.78), and 91 (2.87). ///
		Policy relevance is determined by priority scores in response to the question: ///
		\textit{How much of a priority is this outcome to its policy area?} ///
		Seven undergraduates reported their scores for each trial outcome on a 3-point scale (1-Low, 2-Medium, 3-High). ///
		The most policy relevant nudges are defined as those in the top half of average priority scores. ///
		For the Academic Journals outcomes, the Cronbach's alpha for the scoring is 0.83, and for the Nudge Units, 0.62. ///
		65 percent of Nudge Unit trials are considered low cost interventions, which are either email communications ///
		or cases in which the control group was receiving a status quo communication. ///
		Citations are updated as of March 5, 2020. ///
		Trials with zero citations are assigned a citation count of 1 in the weighting analysis. ///
		See Tables A1a and A1b for the list of published trials and their citation counts. ///
		\end{tablenotes} \end{threeparttable}} \end{table})
}
*****************************************
***TABLE A8: TRADITIONAL META-ANALYSES***
*****************************************
{
	eststo clear
	clear all
	use "./cleaned_data/NudgeUnits.dta"
	gen AJ=0
	append using "./cleaned_data/AcademicJournals.dta", force
	replace AJ=1 if missing(AJ)
	label var AJ "Academic Journals sample"

	**Card, Kluve, and Weber (2018) method
	global threshold 0.01
	gen Ninv = ((1/controlN) + (1/treatmentN))
	gen treatmentvar=.
	gen REweight=1

	forvalues p=0/1 {
		local res1 1
		local res2 2
		local iter 1
		while abs(`res1'-`res2')>$threshold {
			qui reg treatmenteffect if AJ==1-`p' [aweight=REweight]
			local res1 = _b[_cons]
			predict resid, resid
			qui replace treatmentvar = resid^2 if AJ==1-`p'
			eststo s`p': qui reg treatmentvar Ninv if AJ==1-`p', cl(trialnumber)
			estadd scalar itr `iter'
			predict REweightinv
			qui sum REweightinv if REweightinv>0 & AJ==1-`p'
			qui replace REweightinv = `r(min)' if REweightinv<0 & REweightinv!=. & AJ==1-`p'
			qui replace REweight = 1/REweightinv if AJ==1-`p'
			drop resid REweightinv
			qui reg treatmenteffect if AJ==1-`p' [aweight=REweight]
			local res2 = _b[_cons]
			local ++iter
		}
	}
		local res1 1
		local res2 2
		local iter 1
		gen REweightpub=1
		while abs(`res1'-`res2')>$threshold {
			qui reg treatmenteffect if AJ==0 & publication==1 [aweight=REweightpub]
			local res1 = _b[_cons]
			predict resid, resid
			qui replace treatmentvar = resid^2 if AJ==0 & publication==1
			eststo s2: qui reg treatmentvar Ninv if AJ==0 & publication==1, cl(trialnumber)
			estadd scalar itr `iter'
			predict REweightinv
			qui sum REweightinv if REweightinv>0 & AJ==0 & publication==1
			qui replace REweightinv = `r(min)' if REweightinv<0 & REweightinv!=. & AJ==0 & publication==1
			qui replace REweightpub = 1/REweightinv if AJ==0 & publication==1
			drop resid REweightinv
			qui reg treatmenteffect if AJ==0 & publication==1 [aweight=REweightpub]
			local res2 = _b[_cons]
			local ++iter
		}

	gen REweight_restr = REweight
	forvalues p=0/1 {
		qui sum REweight if AJ==`p', d
		replace REweight_restr = `r(p10)' if AJ==`p' & REweight<`r(p10)'
		replace REweight_restr = `r(p90)' if AJ==`p' & REweight>`r(p90)'
		}
	gen REweightpub_restr = REweightpub
	qui sum REweightpub if publication==1, d
	replace REweightpub_restr = `r(p10)' if REweightpub_restr<`r(p10)' & publication==1
	replace REweightpub_restr = `r(p90)' if REweightpub_restr>`r(p90)' & publication==1
		
	forvalues p=0/1 {
		eststo r`p': qui reg treatmenteffect [aweight=REweight_restr] if AJ==1-`p', cl(trialnumber)
		preserve
			drop if AJ!=1-`p'
			collapse (mean) controlN (sum) treatmentN, by(trialnumber trialsample)
			gen N = controlN+treatmentN
			qui sum N
		restore
		local obs = round(`r(sum)')
		estadd scalar obs `obs'
		qui sum controltakeup if AJ==1-`p'
		estadd scalar c `r(mean)'
		qui sum treatmenteffect if AJ==1-`p', d
		estadd scalar median `r(p50)'
		qui sum mde if AJ==1-`p', d
		estadd scalar mde `r(p50)'
		qui sum REweight_restr if AJ==1-`p', d
		local weightdist
			if `p'==1 {
				eststo r2: qui reg treatmenteffect [aweight=REweightpub_restr] if AJ==1-`p' & publication==1, cl(trialnumber)
				preserve
					drop if AJ!=1-`p' | publication!=1
					collapse (mean) controlN (sum) treatmentN, by(trialnumber trialsample)
					gen N = controlN+treatmentN
					qui sum N
				restore
				local obs = round(`r(sum)')
				estadd scalar obs `obs'
				qui sum controltakeup if AJ==1-`p' & publication==1
				estadd scalar c `r(mean)'
				qui sum treatmenteffect if AJ==1-`p' & publication==1, d
				estadd scalar median `r(p50)'
				qui sum mde if AJ==1-`p' & publication==1, d
				estadd scalar mde `r(p50)'
			}
	}

	esttab r*, nonumber se nostar nonotes stat(N N_clust obs c median mde, fmt(0 0 %16.0gc %4.2f %4.2f %4.2f))

	local lastrow=19
	mat results=J(`lastrow',8,.)
	forvalues i=1/3 {
		mat results[`lastrow'-9,2*`i'+1]=r(coefs)[1,2*`i'-1]
		mat results[`lastrow'-8,2*`i'+1]=r(coefs)[1,2*`i']
		mat results[`lastrow'-5,2*`i'+1]=r(stats)[1...,`i']
	}

	local models `" "ml" "ebayes" "dlaird" "'
	forvalues p=0/1 {
		local i=1
		foreach model in `models' {
			qui meta set treatmenteffect SE if AJ==1-`p', random(`model')
			qui meta sum if AJ==1-`p', nostud
			if `p'==0 {
				eststo a`i': qui reg treatmenteffect [aweight=_meta_weight] if AJ==1-`p', cluster(trialnumber)
				qui meta sum if AJ==1-`p', nostud
				estadd scalar tau sqrt(`r(tau2)')
			}
			else if `p'==1 {
				eststo b`i': qui reg treatmenteffect [aweight=_meta_weight] if AJ==1-`p', cluster(trialnumber)
				qui meta sum if AJ==1-`p', nostud
				estadd scalar tau sqrt(`r(tau2)')
			}
			local ++i
			
		}
	}

	local i=1
	foreach model in `models' {
		qui meta set treatmenteffect SE if AJ==0 & publication==1, random(`model')
		qui meta sum if AJ==0 & publication==1, nostud
		eststo c`i': qui reg treatmenteffect [aweight=_meta_weight] if AJ==0 & publication==1, cluster(trialnumber)
		qui meta sum if AJ==0 & publication==1, nostud
		estadd scalar tau sqrt(`r(tau2)')
		local ++i
	}

	gen C1 = round(controltakeup/100*controlN)
	gen C0 = round((1-controltakeup/100)*controlN)
	gen T1 = round(treatmenttakeup/100*treatmentN)
	gen T0 = round((1-treatmenttakeup/100)*treatmentN)

	gen MHwgt = (T0+T1)*(C0+C1)/(T0+T1+C0+C1)
	gen MHwgtlogOR = 1/((1/C0)+(1/C1)+(1/T0)+(1/T1))
	label var MHwgt "Mantel-Haenszel weights for fixed effects model"

	eststo u1: qui reg treatmenteffect if AJ==1, cl(trialnumber)
	estadd scalar tau 0
	eststo u2: qui reg treatmenteffect if AJ==0, cl(trialnumber)
	estadd scalar tau 0
	eststo u3: qui reg treatmenteffect if AJ==0 & publication==1, cl(trialnumber)
	estadd scalar tau 0

	eststo f1: qui reg treatmenteffect [aweight=MHwgt] if AJ==1, cl(trialnumber)
	estadd scalar tau 0
	eststo f2: qui reg treatmenteffect [aweight=MHwgt] if AJ==0, cl(trialnumber)
	estadd scalar tau 0
	eststo f3: qui reg treatmenteffect [aweight=MHwgt] if AJ==0 & publication==1, cl(trialnumber)
	estadd scalar tau 0

	esttab a*, nonumber se nostar nonotes stat(tau, fmt(%4.2f))
	forvalues i=1/3 {
		mat results[2*`i'+2,2+1]=r(coefs)[1,2*`i'-1]
		mat results[2*`i'+1+2,2+1]=r(coefs)[1,2*`i']
		mat results[2*`i'+2,3+1]=r(stats)[1,`i']
	}
	esttab b*, nonumber se nostar nonotes stat(tau, fmt(%4.2f))
	forvalues i=1/3 {
		mat results[2*`i'+2,4+1]=r(coefs)[1,2*`i'-1]
		mat results[2*`i'+1+2,4+1]=r(coefs)[1,2*`i']
		mat results[2*`i'+2,5+1]=r(stats)[1,`i']
	}
	esttab c*, nonumber se nostar nonotes stat(tau, fmt(%4.2f))
	forvalues i=1/3 {
		mat results[2*`i'+2,6+1]=r(coefs)[1,2*`i'-1]
		mat results[2*`i'+1+2,6+1]=r(coefs)[1,2*`i']
		mat results[2*`i'+2,7+1]=r(stats)[1,`i']
	}

	esttab f*, nonumber se nostar stat(tau, fmt(%4.2f))
	forvalues i=1/3 {
		mat results[`lastrow'-7,2*`i'+1]=r(coefs)[1,2*`i'-1]
		mat results[`lastrow'-6,2*`i'+1]=r(coefs)[1,2*`i']
		mat results[`lastrow'-7,2*`i'+2]=r(stats)[1,`i']
	}

	esttab u*, nonumber se nostar stat(tau, fmt(%4.2f))
	forvalues i=1/3 {
		mat results[2,2*`i'+1]=r(coefs)[1,2*`i'-1]
		mat results[3,2*`i'+1]=r(coefs)[1,2*`i']
	}

	mata
	results=strofreal(st_matrix("results"))
	results[1,1]=""
	results[1,3]="ATE (pp.)"
	results[1,4]="$ \hat{\tau} $"
	results[1,5]="ATE (pp.)"
	results[1,6]="$ \hat{\tau} $"
	results[1,7]="ATE (pp.)"
	results[1,8]="$ \hat{\tau} $"

	results[1,2]="distributional assumption"
	results[2,2]="None"
	results[3,2]=""
	results[4,2]="Normal"
	results[5,2]=""
	results[6,2]="Normal"
	results[7,2]=""
	results[8,2]="None"
	results[9,2]=""
	results[10,2]="None"
	results[11,2]=""
	results[12,2]="Degenerate"

	results[2,1]="Unweighted"
	results[3,1]=""
	results[4,1]="Maximum Likelihood"
	results[5,1]=""
	results[6,1]="Empirical Bayes"
	results[7,1]=""
	results[8,1]="DerSimonian-Laird"
	results[9,1]=""
	results[10,1]="Card, Kluve, and Weber (2018)"
	results[11,1]=""
	results[12,1]="Fixed effect"
	results[13,1]=""

	results[`lastrow'-5,1]="%Nudges"
	results[`lastrow'-4,1]="%Trials"
	results[`lastrow'-3,1]="%Observations"
	results[`lastrow'-2,1]="%Avg. control take-up"
	results[`lastrow'-1,1]="%Median treatment effect"
	results[`lastrow',1]="%Median MDE"
	end

	forvalues i=3(2)13 {
		forvalues j=4(2)8 {
		mata: results[`i',`j']=""
		}
	}


	forvalues i=0/6 {
		mata: results[`lastrow'-`i',2]=""
		forvalues j=3(2)7 {
			mata: results[`lastrow'-`i',`j'+1]=""
		}
	}

	forvalues i=0(2)5 {
		local x = string(results[`lastrow'-3,2+`i'+1],"%12.0gc")
		mata: results[`lastrow'-3,2+`i'+1] = "`x'"
		}

	local end=`lastrow'-7
	forvalues j=2(2)`end' {
		forvalues i=0/5 {
		local x = string(results[`j',2+`i'+1],"%4.2f")
		mata: results[`j',2+`i'+1] = "`x'"
		}
	}

	local end=`lastrow'-6
	forvalues j=3(2)`end' {
		forvalues i=0(2)4 {
		local x = "("+string(results[`j',2+`i'+1],"%4.2f")+")"
		mata: results[`j',2+`i'+1] = "`x'"
		}
	}
		
	local start=`lastrow'-2
	forvalues j=`start'/`lastrow' {
		forvalues i=0(2)4 {
		local x = string(results[`j',2+`i'+1],"%4.2f")
		mata: results[`j',2+`i'+1] = "`x'"
		}
	}


	forvalues j=4(2)8 {
		mata: results[2',`j']="--"
		mata: results[10',`j']="--"
	}
	
	local hline=`lastrow'-5

	mmat2tex results using "./output/tables_final/MetaAnalyses.tex", ///
		replace fmt("%4.2f") ///
		preheader(\begin{table}[htbp!] \centering \large{\begin{threeparttable} ///
		\caption{Traditional meta-analysis models (without correction for selective publication)} \begin{tabular} {l c c c c c c c} \toprule ///
			& &\multicolumn{2}{c}{Academic Journals}&\multicolumn{2}{c}{Nudge Units}&\multicolumn{2}{c}{Published Nudge Units} ///
		\\\cmidrule(lr){3-4}\cmidrule(lr){5-6}\cmidrule(lr){7-8} ///
		& True study-level effects & (1) & (2) & (3) & (4) & (5) & (6) \\ ) ///
		postheader(\hline) ///
		bottom(\bottomrule \end{tabular} \label{tab:models} ///
		\begin{tablenotes} \small ///
		\item This table shows the average treatment effects using various meta-analysis methods. ///
		Standard errors clustered by trial are shown in parentheses. ///
		$ \hat{\tau} $ is the estimated standard deviation in between-study true effect sizes. ///
		Following Card, Kluve, and Weber (2018), we winsorize weights from their method at ///
		the 10th and 90th percentiles. ///
		Mantel-Haenszel weights are used for the fixed-effect model. ///
		\end{tablenotes} \end{threeparttable}} \end{table})
}