clear
rng(1);

% Table 6

%% Model selection - 1 for Academic Journals, 0 for Nudge Units
effect=1     % Effect size distribution
power=1      % Statistical power distribution
pubbias=1    % Turn on/off publication bias

ntrials=152; % Number of trials in each simulation round
nsim=1000;   % Number of simulation rounds

%% Parameters: mu1 mu2 bt1 bt2 wi1 wi2 p(N1) gamma
AJParam=[1.30 19.18 2.70 5.86 0.05 12.73 0.86 0.10];
NUParam=[0.35 5.09  0.41 4.64 0.23 6.40  0.78 1.00];

%% Load data
AJ=readtable('cleaned_data/MATLAB/Academic Journals.csv');
AJ=sortrows(AJ,'trialnumber');
AJTrial=table2array(AJ(:,{'trialnumber'}));
AJTrial=round(AJTrial*100);
AJTrial=findgroups(AJTrial);
AJTE=table2array(AJ(:,{'treatmenteffect'}));
AJSE=table2array(AJ(:,{'SE'}));

NU=readtable('cleaned_data/MATLAB/Nudge Units.csv');
NU=sortrows(NU,'trialnumber');
NUTrial=table2array(NU(:,{'trialnumber'}));
NUTrial=round(NUTrial*100);
NUTrial=findgroups(NUTrial);
NUTE=table2array(NU(:,{'treatmenteffect'}));
NUSE=table2array(NU(:,{'SE'}));


%% Simulation
if effect==1
    mu1=AJParam(1);
    mu2=AJParam(2);
    sd1=AJParam(3);
    sd2=AJParam(4);
    wi1=AJParam(5);
    wi2=AJParam(6);
    q=AJParam(7);
elseif effect==0
    mu1=NUParam(1);
    mu2=NUParam(2);
    sd1=NUParam(3);
    sd2=NUParam(4);
    wi1=NUParam(5);
    wi2=NUParam(6);
    q=NUParam(7);
end

if power==1
    Trial=AJTrial;
    SE=AJSE;
elseif power==0
    Trial=NUTrial;
    SE=NUSE;
end

if pubbias==1
    pubprobinsig=AJParam(8);
elseif pubbias==0
    pubprobinsig=NUParam(8);
end
    
grandindex=randsample(max(Trial),nsim*ntrials,true);
grandindex=reshape(grandindex,ntrials,[]);
atevec=[];

for c=1:nsim
    index=grandindex(:,c);
    se=[];
    te=[];
    id=[];
    whichnormalvec=[];
    for m=1:max(Trial)
        repcount=sum(index==m); % number of trials trial m got chosen
        for j=1:repcount
            id=[id;repmat(m*ntrials+j,length(SE(Trial==m)),1)]; % create unique IDs for each random draw of trial m
        end
        se=[se;repmat(SE(Trial==m),repcount,1)]; % empirical SEs
        random=rand(repcount,1);
        whichnormal=1*(random<=q)+2*(random>q);
        basete=normrnd(mu1,sd1,repcount,1);
        basete(whichnormal==2)=normrnd(mu2,sd2,sum(whichnormal==2),1);
        te=[te;repelem(basete,length(SE(Trial==m)),1)];
        whichnormalvec=[whichnormalvec;repelem(whichnormal,length(SE(Trial==m)),1)];
    end
    id=findgroups(id);

    te_=normrnd(te,(wi1^2+se.^2).^0.5);
    te_(whichnormalvec==2)=normrnd(te(whichnormalvec==2),(wi2^2+se(whichnormalvec==2).^2).^0.5);
    basete=te;
    te=te_;

    triallevel= [...
        accumarray(id,id,[],@mean),...
        accumarray(id,id,[],@sum),...
        accumarray(id,te./se,[],@max)...
        ];
    keep=triallevel(:,1)>0;
    triallevel=triallevel(keep,:);
    arms=triallevel(:,2)./triallevel(:,1);

    data=[triallevel(:,1) triallevel(:,3)];
    append=[];
    for k=1:max(arms)
        cond=arms==k;
        add=repmat(data(cond,:),k,1);
        append=[append;add];
    end
    append=sortrows(append,1);
    keep=append(:,2)>=1.96;
    keep=logical(keep+(1-keep).*binornd(1,pubprobinsig,size(keep,1),size(keep,2)));
    atevec=[atevec;nanmean(te(keep))];
end
ate=mean(atevec)
sd=sqrt(var(atevec))