clear;
warning('off','stats:mvtcdfqmc:HighCorr');
spmd
    warning('off','stats:mvtcdfqmc:HighCorr');
end
rng(1);

% Estimates generalized meta-analysis models (Tables 5 and A9)

%% Settings
dataset=0   % 0 - Academic Journals; 1 - Nudge Units; 2 - Published Nudge Units; 3 - Stacked (Academic Journals + Nudge Units)
normals=2   % Number of normal distributions to model effect sizes (1, 2, or 3)
estbias=0   % 0 - Assume P(Publish|Insignificant)=P(Publish|Significant); 1 - Estimate the relative probability; 2 - Estimate the relative probability for the Academic Journal sample only (applies only in stacked dataset)
columns={}
    % Leave blank to non-parametrically estimate the probability of drawing effects from each normal distribution
    % Otherwise, specify column 1names to include in the ordinal probit, e.g.,
        % {'AJ','medium_inperson','controlreceivescomm','pol_work','mech_choicedesign'} % Table A9c Col 3
        % {'AJ','medium_email','medium_inperson','controlreceivescomm','pol_work','pol_cons','mech_choicedesign','mech_framing'} % Table A9c Col 4

initial=[0 5 20 1 1 1 1 1 1 norminv(1/3) norminv(2/3) 1] % Initial values for gridsch=0
    % Initial values: [mu1 mu2 mu3 wi1 wi2 wi3 bt1 bt2 bt3 theta1 theta2 gamma Beta]
    % Length of 'Beta' should be the number of variables selected in 'columns'
    % Results can be sensitive to initial values. Estimates in the paper
    % were found by initializing from multiple plausible points in a grid
    % and selecting the best fit.
    % To start from estimates in the paper:
        % Table 5
        % initial=[8.58 100    100   7.89   1    1    5.65   1     1     2             3                  1];    % AJ 1N Gamma=1
        % initial=[1.50 100    100   3.04   1    1    2.38   1     1     2             3                  1];    % NU 1N Gamma=1
        % initial=[1.30 19.184 100   2.7031 5.86 1    0.0469 12.73 1     1.06          3                  0.1016];  % AJ 2N
        % initial=[0.35 5.09   100   0.41   4.64 1    0.23   6.4   1     norminv(0.78) 3                  1];    % NU 2N Gamma=1
        % Table A9a
        % initial=[5.19 100   100   9    1    1    5.47 1     1     2             3                  0.25]; % AJ 1N
        % initial=[0.68 100   100   0.45 1    1    0.14 1     1     2             3                  1];    % PubNU 1N Gamma=1
        % initial=[0.35 100   100   0.42 1    1    0.13 1     1     2             3                  0.07]; % PubNU 1N
        % initial=[3.09 20.43 100   2.48 5.44 1    0.05 12.41 1     norminv(0.69) 3                  1];    % AJ 2N Gamma=1
        % initial=[0.47 2.74  100   0.29 0.01 1    0.13 0.01  1     norminv(0.74) 3                  1];    % PubNU 2N Gamma=1
        % initial=[0.09 0.75  100   0.08 0.11 1    0.04 0.17  1     norminv(0.59) 3                  0.07]; % PubNU 2N
        % initial=[0.26 3.11  19.21 0.17 2.88 5.91 0.03 0.01  12.8  norminv(0.59) norminv(0.59+0.30) 0.07]; % AJ 3N
        % initial=[0.21 2.34  8.54  0.28 1.83 0.01 0.10 0.66  13.21 norminv(0.61) norminv(0.61+0.32) 1];    % NU 3N Gamma=1
        % Table A9c
        % initial=[0.22 2.83 14.90 0.29 2.06 6.77 0.10 0.66 12.88 0.33 1.58 1 1.22]; % Column 1
        % initial=[0.22 2.59 13.34 0.28 2.11 7.80 0.10 0.66 12.95 0.33 1.50 0.07 0.34]; % Column 2
        % initial=[0.22 2.62 13.33 0.28 2.16 7.82 0.10 0.66 13.01 0.34 1.65 0.08 -0.04 1.48 0.06 -0.56 0.91]; % Column 3
        % initial=[0.22 2.63 13.34 0.28 2.16 7.85 0.10 0.66 13.04 0.43 1.76 0.08 -0.01 -0.08 1.48 0.00 -0.51 -0.72 0.94 0.40]; % Column 4
        
gridsch=0   % 0 - Estimate from pre-specified initial values; 1 - Estimate over random grid of initial values (requires btstpse=0)
gridnum=1   % If gridsch=1, specify number of times to estimate from random initial values
initiallb=[0 0  0  0 0 0  0 0 0  -1 1 0 repmat(-2,1,length(columns))]; % Lower bound of initial values for gridsch=1
initialub=[2 10 20 1 5 10 1 2 15  1 3 1 repmat(2,1,length(columns))]; % Upper bound of initial values for gridsch=1

btstpse=0   % 0 - Estimate point estimates; 1 - Find bootstrap standard errors 
btstpid=[]; 
            % If btstpse=1, select which bootstrap samples to use from 1-2000.
            % For the standard errors in the paper:
                % Table 5
                % [1:200]   % AJ 1N Gamma=1
                % [201:400] % NU 1N Gamma=1
                % [401:600] % AJ 2N
                % [601:800] % NU 2N Gamma=1
                % Table A9a
                % [201:400] % AJ 1N
                % [201:400] % PubNU 1N Gamma=1
                % [1:200]   % PubNU 1N
                % [601:800] % AJ 2N Gamma=1
                % [401:600] % PubNU 2N Gamma=1
                % [601:800] % PubNU 2N
                % [801:1000]% AJ 3N
                % [801:1000]% NU 3N Gamma=1
                % Table A9c
                % [1801:1850] % Column 1
                % [1851:1900] % Column 2
                % [1901:1950] % Column 3
                % [1751:1800,1951:2000] % Column 4

assert(btstpse+gridsch<=1,'Bootstrap and gridsearch cannot be done simultaneously.')
        
%% Load data
if dataset==0
    if btstpse==0
        data=readtable('cleaned_data/MATLAB/Academic Journals.csv');
        data.AJ=ones(size(data,1),1);
    elseif btstpse==1
        data=readtable('cleaned_data/MATLAB/Academic Journals Bootstrap.csv');
        data.AJ=ones(size(data,1),1);
    end
elseif dataset>0
    if dataset==2 & btstpse==1
        data=readtable('cleaned_data/MATLAB/Published Nudge Units Bootstrap.csv');
        data.AJ=zeros(size(data,1),1);
    elseif btstpse==1
        data=readtable('cleaned_data/MATLAB/Nudge Units Bootstrap.csv');
        data.AJ=zeros(size(data,1),1);
    elseif btstpse==0
        data=readtable('cleaned_data/MATLAB/Nudge Units.csv');
        data.AJ=zeros(size(data,1),1);
        if dataset==2
            data=data(data.publication==1,:);
        end
    end     
    if dataset==3
        if btstpse==0
            data2=readtable('cleaned_data/MATLAB/Academic Journals.csv');
            data2.AJ=ones(size(data2,1),1);
            data=[data;data2];
            clear data2
        elseif btstpse==1
            data2=readtable('cleaned_data/MATLAB/Academic Journals Bootstrap.csv');
            data2.AJ=ones(size(data2,1),1);
            data=[data;data2];
            clear data2         
        end
    end
end
if btstpse==0
    data=sortrows(data,'trialnumber');
    id=table2array(data(:,{'trialnumber'}));
    id=round(id*100);
    id=findgroups(id);
    TE=table2array(data(:,{'treatmenteffect'}));
    SE=table2array(data(:,{'SE'}));
    AJ=table2array(data(:,{'AJ'}));
    X=[table2array(data(:,columns)),zeros(length(id),1)]; % Add constant variable of 0 so the code runs when there are no controls selected
elseif btstpse==1
    id=table2array(data(:,{'id'}));
    TE=table2array(data(:,{'treatmenteffect'}));
    SE=table2array(data(:,{'SE'}));
    AJ=table2array(data(:,{'AJ'}));
    if dataset==3
        id(AJ==1)=id(AJ==1)+max(id(AJ==0)); % since both NU and AJ bootstrap samples start numbering trials at 1 
    end
    X=[table2array(data(:,columns)),zeros(length(id),1)]; % Add constant variable of 0 so the code runs when there are no controls selected
    bs=table2array(data(:,{'bssample'})); % Bootstrap sample number
end
    
%% Estimation
% Constraints A*par<=B
A=[1 -1  0 0 0 0 0 0 0 0  0 0 zeros(1,length(columns)+1);  % mu1<=mu2
   0  1 -1 0 0 0 0 0 0 0  0 0 zeros(1,length(columns)+1);  % mu2<=mu3
   0  0  0 0 0 0 0 0 0 1 -1 0 zeros(1,length(columns)+1)]; % theta1<=theta2
b=[0; 0; 0];
lb=[-100 -100 -100 0   0   0   0   0   0   -2 -2 0  repmat(-100,1,length(columns)+1)]; % lower bound
ub=[ 100  100  100 100 100 100 100 100 100  2  3 10 repmat(100,1,length(columns)+1)]; % upper bound
initial=[initial, 0]; % This extra 0 is for the coefficient on the constant variable of zeros (no meaning; just so code runs)

if btstpse==0 & gridsch==0
    options=optimoptions('patternsearch','Display','iter','UseParallel',true,'UseVectorized',false);
    LLH=@(param) est(param,id,TE,SE,AJ,X,estbias,normals);
    [par,mLLH,ef,op]=patternsearch(LLH,initial,A,b,[],[],lb,ub,options); % Estimate parameters
    [LLH,LLHNU,LLHAJ,pNU,pAJ,ATENU,ATEAJ,ATENUatAJ,ATEAJatNU]=est(par,id,TE,SE,AJ,X,estbias,normals) % Get results from estimated parameters
    par=par(1:end-1); % Remove the meaningless coefficient on the constant variable of zeros
    % Present results
    if normals<3
        par(3)=NaN;
        par(6)=NaN;
        par(9)=NaN;
        par(11)=NaN;
        if normals<2
            par(2)=NaN;
            par(5)=NaN;
            par(8)=NaN;
            par(10)=NaN;
        end
    end
    if isnan(ATEAJ), gAJ=NaN; else gAJ=(estbias==0)+(1-(estbias==0))*par(12); end % fill in publication bias probability in result table
    if isnan(ATENU), gNU=NaN; else gNU=(1-(estbias==1))+(estbias==1)*par(12); end % fill in publication bias probability in result table
    results=[reshape(par(1:9),3,3),pAJ',pNU';...
             NaN,NaN,NaN,ATEAJ,ATENU;...
             NaN,NaN,NaN,gAJ,gNU;...
             NaN,NaN,NaN,LLHAJ,LLHNU];
    results=array2table(results,...
                        'VariableNames',{'Mean','BetweenSD','WithinSD','ProbNormAcadJour','ProbNormNudgeUnits'},...
                        'RowNames',{'Normal1','Normal2','Normal3','ATE','InsigPubProb','LLH'}...
                        )
elseif gridsch==1
    initiallb=[initiallb, 0]; % This extra 0 is for the coefficient on the constant variable of zeros (no meaning; just so code runs)
    initialub=[initialub, 0]; % This extra 0 is for the coefficient on the constant variable of zeros (no meaning; just so code runs)
    initialgd=[initiallb+rand(gridnum,length(initiallb)).*(initialub-initiallb)]; % Randomly generate initial values between lower and upper bound
    
    % Reorganizes random grid so that initial values have mu1<=mu2<=mu3 and theta1<=theta2
    index=initialgd(:,1)>initialgd(:,2);
    placeholder=initialgd(index,1);
    initialgd(index,1)=initialgd(index,2);
    initialgd(index,2)=placeholder;
    index=initialgd(:,2)>initialgd(:,3);
    placeholder=initialgd(index,2);
    initialgd(index,2)=initialgd(index,3);
    initialgd(index,3)=placeholder;
    index=initialgd(:,1)>initialgd(:,2);
    placeholder=initialgd(index,1);
    initialgd(index,1)=initialgd(index,2);
    initialgd(index,2)=placeholder;
    index=initialgd(:,10)>initialgd(:,11);
    placeholder=initialgd(index,10);
    initialgd(index,10)=initialgd(index,11);
    initialgd(index,10)=placeholder;
    clear placeholder index
    
    options=optimoptions('patternsearch','UseParallel',true,'UseVectorized',false);
    gridres=zeros(gridnum,2*(length(initiallb)-1)+3+3+3+4+1); % Initial values, parameter estimates, 3 LLH, 3 pAJ, 3 pNU, 4 ATEs, 1 exitflag
    for m=1:gridnum
        m % display grid row number
        initial=initialgd(m,:);
        try
            LLH=@(param) est(param,id,TE,SE,AJ,X,estbias,normals);
            [par,mLLH,ef,op]=patternsearch(LLH,initial,A,b,[],[],lb,ub,options); % Estimate parameters
            [LLH,LLHNU,LLHAJ,pNU,pAJ,ATENU,ATEAJ,ATENUatAJ,ATEAJatNU]=est(par,id,TE,SE,AJ,X,estbias,normals) % Get results from estimated parameters
            par=par(1:end-1);
            initial=initial(1:end-1);
            res=[initial,par,LLH,LLHNU,LLHAJ,pNU,pAJ,ATENU,ATEAJ,ATENUatAJ,ATEAJatNU,ef];
            gridres(m,:)=res;
        catch
        end
    end    
elseif btstpse==1
    options=optimoptions('patternsearch','UseParallel',true,'UseVectorized',false);
    bsres=zeros(size(btstpid,2),12+length(columns)+3+3+3+4+1+1); % 12 base parameters, Betas, 3 LLH, 3 pAJ, 3 pNU, 4 ATEs, 1 bootstrap sample num, 1 exitflag
    for m=btstpid
        m % display bootstrap sample number
        idbs=id(bs==m);
        TEbs=TE(bs==m);
        SEbs=SE(bs==m);
        AJbs=AJ(bs==m);
        Xbs=X(bs==m,:);
        try
            LLH=@(param) est(param,idbs,TEbs,SEbs,AJbs,Xbs,estbias,normals);
            [par,mLLH,ef,op]=patternsearch(LLH,initial,A,b,[],[],lb,ub,options); % Estimate parameters
            [LLH,LLHNU,LLHAJ,pNU,pAJ,ATENU,ATEAJ,ATENUatAJ,ATEAJatNU]=est(par,idbs,TEbs,SEbs,AJbs,Xbs,estbias,normals) % Get results from estimated parameters
            par=par(1:end-1);
            res=[par,LLH,LLHNU,LLHAJ,pNU,pAJ,ATENU,ATEAJ,ATENUatAJ,ATEAJatNU,m,ef];
            bsres(m-min(btstpid)+1,:)=res;
        catch
        end
    end
    if normals<3
        bsres(:,[3,6,9,11])=NaN;
        if normals<2
            bsres(:,[2,5,8,10])=NaN;
        end
    end
    if estbias==0
        bsres(:,12)=NaN;
    end
    converged=(bsres(:,end)==1 & bsres(:,length(par)+1)~=-Inf & bsres(:,length(par)+1)~=Inf); % exitflag=1 & LLH not -Inf
    bsres_conv=bsres(converged,:);
    bspar_9505=prctile(bsres_conv,95,1)-prctile(bsres_conv,5,1);
    bspar_9505(bspar_9505==0)=0.1;
    corner_low=sum(bsres_conv(:,1:12)<prctile(bsres_conv(:,12),5,1)-10*bspar_9505(1:12),2); % filter for low corner solutions
    corner_high=sum(bsres_conv(:,1:12)>prctile(bsres_conv(:,12),95,1)+10*bspar_9505(1:12),2); % filter for high corner solutions
    if length(par)>12
        corner_low=corner_low + sum(bsres_conv(:,13:length(par))<-5,2); % filter for low corner solutions in ordinal probit coefficients
        corner_high=corner_high + sum(bsres_conv(:,13:length(par))>5,2); % filter for high corner solutions in ordinal probit coefficients
    end
    bsres_final=bsres_conv(corner_low==0&corner_high==0,:); % keep non-corner solutions
    bsse=var(bsres_final).^0.5
    disp("Order: mu1, mu2, mu3, btsd1, btsd2, btsd3, wisd1, wisd2, wisd3, theta1, theta2, gamma, Betas, LLHall, LLHNU, LLHAJ, P(Normals) for NU, P(Normals) for AJ, ATE_NU, ATE_AJ, ATE_NU at X_AJ, ATE_AJ at NU, bootstrap sample num, exitflag")
end

%% Function
function [LLH,LLHNU,LLHAJ,pNU,pAJ,ATENU,ATEAJ,ATENUatAJ,ATEAJatNU]=est(param,id,TE,SE,AJ,X,estbias,normals)
    mu1=param(1);
    mu2=param(2);
    mu3=param(3);
    bt1=param(4);
    bt2=param(5);
    bt3=param(6);
    wi1=param(7);
    wi2=param(8);
    wi3=param(9);
    if normals==1
        theta1=1e10;
        theta2=1e100;
        Beta=zeros(1,length(param(13:end)));
    elseif normals==2
        Beta=param(13:end);
        theta1=param(10);
        theta2=1e100;
    elseif normals==3
        Beta=param(13:end);
        theta1=param(10);
        theta2=param(11);       
    end
    pubbias=param(12);
        
    triallevel=[accumarray(id,id,[],@mean),...
                accumarray(id,TE./SE,[],@max),...
                accumarray(id,AJ,[],@mean)...
               ];
    index=triallevel(:,1)>0;
    triallevel=triallevel(index,:);
    trialsig=triallevel(:,2)>=1.96;
    AJtr=triallevel(:,3);
    if estbias==0
        phat=ones(length(triallevel),1);
    elseif estbias==1
        phat=(trialsig)+(1-trialsig)*pubbias;
    elseif estbias==2
        phat=or(trialsig==1,AJtr==0)+(1-or(trialsig==1,AJtr==0))*pubbias;
    end
    
    PrAllInsig=[];
    fX=[];
    for m=min(id):max(id)
        x=mean(X(id==m,:),1);
        te=TE(id==m);
        se=SE(id==m);
        k=length(te);
        if k>0
            qL=x*Beta';
            q1=normcdf(theta1-qL);
            q2=normcdf(theta2-qL)-q1;
            q3=1-q1-q2;
            wisd1=repmat(wi1,k,1);
            wisd2=repmat(wi2,k,1);
            wisd3=repmat(wi3,k,1);
            VarCov1=repmat(bt1^2,k)+diag(se.^2)+diag(wisd1.^2);
            VarCov2=repmat(bt2^2,k)+diag(se.^2)+diag(wisd2.^2);
            VarCov3=repmat(bt3^2,k)+diag(se.^2)+diag(wisd3.^2);
            if estbias>0
                f1=mvncdf(repmat(-Inf,k,1).*se,repmat(1.96,k,1).*se,repmat(mu1,k,1),VarCov1);
                f=q1*f1;
                if normals>1
                    f2=mvncdf(repmat(-Inf,k,1).*se,repmat(1.96,k,1).*se,repmat(mu2,k,1),VarCov2);
                    f=f+q2*f2;
                    if normals>2
                        f3=mvncdf(repmat(-Inf,k,1).*se,repmat(1.96,k,1).*se,repmat(mu3,k,1),VarCov3);
                        f=f+q3*f3;
                    end
                end
                PrAllInsig=[PrAllInsig;f];
            else
                PrAllInsig=[PrAllInsig;0];
            end
            
            fx1=mvnpdf(te',mu1,VarCov1);
            fx=q1*fx1;
            if normals>1
                fx2=mvnpdf(te',mu2,VarCov2);
                fx=fx+q2*fx2;
                if normals>2
                    fx3=mvnpdf(te',mu3,VarCov3);
                    fx=fx+q3*fx3;
                end
            end
            fX=[fX;fx];
        end
    end
    if estbias==2
        nc=(AJtr==0)+(1-(AJtr==0)).*(PrAllInsig*pubbias+(1-PrAllInsig));
    else
        nc=PrAllInsig*pubbias+(1-PrAllInsig);
    end
    
    logL=log(phat)-log(nc)+log(fX);
    
    LLH=-sum(logL);
    LLHNU=-sum(logL(AJtr==0));
    LLHAJ=-sum(logL(AJtr==1));
    
    XNU=mean(X(AJ==0,:),1);
    XAJ=mean(X(AJ==1,:),1);
    qNU=XNU*Beta';
    qAJ=XAJ*Beta';
    
    XNUatAJ=XAJ;
    XNUatAJ(1)=0;
    XAJatNU=XNU;
    XAJatNU(1)=1;
    qNUatAJ=XNUatAJ*Beta';
    qAJatNU=XAJatNU*Beta';

    pNU=[normcdf(theta1-qNU), normcdf(theta2-qNU)-normcdf(theta1-qNU), 1-normcdf(theta2-qNU)];
    pAJ=[normcdf(theta1-qAJ), normcdf(theta2-qAJ)-normcdf(theta1-qAJ), 1-normcdf(theta2-qAJ)];
    
    pNUatAJ=[normcdf(theta1-qNUatAJ), normcdf(theta2-qNUatAJ)-normcdf(theta1-qNUatAJ), 1-normcdf(theta2-qNUatAJ)];
    pAJatNU=[normcdf(theta1-qAJatNU), normcdf(theta2-qAJatNU)-normcdf(theta1-qAJatNU), 1-normcdf(theta2-qAJatNU)];
    
    mu=[mu1 mu2 mu3];
    ATENU=pNU*mu';
    ATEAJ=pAJ*mu';
    
    ATENUatAJ=pNUatAJ*mu';
    ATEAJatNU=pAJatNU*mu';
end