#######################
###t-stat histograms###
#######################

# Load data
OESBIT = read.csv("./cleaned_data/R/OESBIT.csv")
HMB = read.csv("./cleaned_data/R/HummelMaedcheBenartzi.csv")
Brodeur = read.csv("./cleaned_data/R/Brodeur.csv")
BrodeurMaxt = read.csv("./cleaned_data/R/BrodeurMaxt.csv")
OESBITMS = OESBIT[OESBIT$mostsig==1,]
HMBMS = HMB[HMB$mostsig==1,]

# Winsorize for visibility
OESBIT$t[OESBIT$t < -3.96] <- -4.46
OESBIT$t[OESBIT$t > 5.96] <- 6.46
OESBITMS$t[OESBITMS$t < -3.96] <- -4.46
OESBITMS$t[OESBITMS$t > 5.96] <- 6.46
HMB$t[HMB$t < -3.96] <- -4.46
HMB$t[HMB$t > 5.96] <- 6.46
HMBMS$t[HMBMS$t < -3.96] <- -4.46
HMBMS$t[HMBMS$t > 5.96] <- 6.46
Brodeur$t[Brodeur$t < -3.96] <- -4.46
Brodeur$t[Brodeur$t > 5.96] <- 6.46
BrodeurMaxt$t[BrodeurMaxt$t < -3.96] <- -4.46
BrodeurMaxt$t[BrodeurMaxt$t > 5.96] <- 6.46

## Generate figures

# Figures 5b,c
pdf("./output/figures_final/HMB_tstat.pdf",width=9,height=6)
hist(HMB$t,
     col="light blue",
     breaks=c(-4.46,-3.96,-3.46,-2.96,-2.46,-1.96,-1.46,-0.96,-0.48,0,0.48,0.96,1.46,1.96,2.46,2.96,3.46,3.96,4.46,4.96,5.46,5.96,6.46),
     axes=F,
     xlab="t=Effect size/Standard error",
     cex.lab=1.5,
     main="",
     freq=TRUE
)
axis(1, at=c(-4.21,-2.96,-1.96,-0.96,0,0.96,1.96,2.96,3.96,4.96,6.21),
     labels=c("<-3.96","-2.96","-1.96","-0.96","0","0.96","1.96","2.96","3.96","4.96",">5.96"))
axis(2)
abline(v=c(-1.96,0,1.96),lty=c(1,2,1),lwd=c(2,2,2))
dev.off()

pdf("./output/figures_final/HMB_tstat_MostSig.pdf",width=9,height=6)
hist(HMBMS$t,
     col="light blue",
     breaks=c(-4.46,-3.96,-3.46,-2.96,-2.46,-1.96,-1.46,-0.96,-0.48,0,0.48,0.96,1.46,1.96,2.46,2.96,3.46,3.96,4.46,4.96,5.46,5.96,6.46),
     axes=F,
     xlab="t=Effect size/Standard error",
     cex.lab=1.5,
     main="",
     freq=TRUE
)
axis(1, at=c(-4.21,-2.96,-1.96,-0.96,0,0.96,1.96,2.96,3.96,4.96,6.21),
     labels=c("<-3.96","-2.96","-1.96","-0.96","0","0.96","1.96","2.96","3.96","4.96",">5.96"))
axis(2)
abline(v=c(-1.96,0,1.96),lty=c(1,2,1),lwd=c(2,2,2))
dev.off()





# Figures 6b,c
pdf("./output/figures_final/OESBIT_tstat.pdf",width=9,height=6)
hist(OESBIT$t,
     col="light blue",
     breaks=c(-4.46,-3.96,-3.46,-2.96,-2.46,-1.96,-1.46,-0.96,-0.48,0,0.48,0.96,1.46,1.96,2.46,2.96,3.46,3.96,4.46,4.96,5.46,5.96,6.46),
     axes=F,
     xlab="t=Effect size/Standard error",
     cex.lab=1.5,
     ylim=c(0,50),
     main="",
     freq=TRUE
)
axis(1, at=c(-4.21,-2.96,-1.96,-0.96,0,0.96,1.96,2.96,3.96,4.96,6.21),
     labels=c("<-3.96","-2.96","-1.96","-0.96","0","0.96","1.96","2.96","3.96","4.96",">5.96"))
axis(2, at=seq(0,50,10), labels=c(0,10,20,30,40,50))
abline(v=c(-1.96,0,1.96),lty=c(1,2,1),lwd=c(2,2,2))
dev.off()

pdf("./output/figures_final/OESBIT_tstat_MostSig.pdf",width=9,height=6)
hist(OESBITMS$t,
     col="light blue",
     breaks=c(-4.46,-3.96,-3.46,-2.96,-2.46,-1.96,-1.46,-0.96,-0.48,0,0.48,0.96,1.46,1.96,2.46,2.96,3.46,3.96,4.46,4.96,5.46,5.96,6.46),
     axes=F,
     xlab="t=Effect size/Standard error",
     cex.lab=1.5,
     ylim=c(0,30),
     main="",
     freq=TRUE
)
axis(1, at=c(-4.21,-2.96,-1.96,-0.96,0,0.96,1.96,2.96,3.96,4.96,6.21),
     labels=c("<-3.96","-2.96","-1.96","-0.96","0","0.96","1.96","2.96","3.96","4.96",">5.96"))
axis(2, yaxp=c(0,30,6))
abline(v=c(-1.96,0,1.96),lty=c(1,2,1),lwd=c(2,2,2))
dev.off()





# Figures A5g-j
pdf("./output/figures_final/HMB_tstat_zoom.pdf",width=9,height=6)
x<-length(HMB$t[HMB$t>3])
y<-length(HMB$t[HMB$t<0])
notes<-paste(x,"arms with t>3 and",y,"arms with t<0 not shown")
h <- hist(HMB$t[HMB$t<=3 & HMB$t>=0],
          col="light blue",
          breaks=c(0,0.15,0.3,0.45,0.6,0.75,0.9,
                   1.05,1.2,1.35,1.5,1.65,1.805,1.96,
                   2.1,2.25,2.4,2.55,2.7,2.85,3),
          axes=F,
          xlab="All t-stats",
          cex.lab=1.5,
          ylim=c(0,5.25),
          main="Academic Journals",
          freq=TRUE
)
adj.old <- par()$adj
par(adj=0)
title(sub=notes)
par(adj = adj.old)
text(h$mids,h$counts,labels=h$counts, adj=c(0.5, -0.5))
axis(1, at=c(0,0.6,1.2,1.65,1.96,2.4,3), 
     labels=c("0","0.6","1.2","1.65","1.96","2.4","3"))
axis(2, at=seq(0,5,1), labels=seq(0,5,1))
abline(v=c(0,1.96),lty=c(2,1),lwd=c(2,2))
abline(v=c(0,1.65),lty=c(2,1),lwd=c(2,2))
dev.off()
rm(h)

pdf("./output/figures_final/HMB_tstat_MostSig_zoom.pdf",width=9,height=6)
x<-length(HMBMS$t[HMBMS$t>3])
y<-length(HMBMS$t[HMBMS$t<0])
notes<-paste(x,"trials with max-t>3 and",y,"trials with max-t<0 not shown")
h <- hist(HMBMS$t[HMBMS$t<=3 & HMBMS$t>=0],
          col="light blue",
          breaks=c(0,0.15,0.3,0.45,0.6,0.75,0.9,
                   1.05,1.2,1.35,1.5,1.65,1.805,1.96,
                   2.1,2.25,2.4,2.55,2.7,2.85,3),
          axes=F,
          xlab="Max t-stat within each trial only",
          cex.lab=1.5,
          ylim=c(0,3.25),
          main="Academic Journals",
          freq=TRUE
)
adj.old <- par()$adj
par(adj=0)
title(sub=notes)
par(adj = adj.old)
text(h$mids,h$counts,labels=h$counts, adj=c(0.5, -0.5))
axis(1, at=c(0,0.6,1.2,1.65,1.96,2.4,3), 
     labels=c("0","0.6","1.2","1.65","1.96","2.4","3"))
axis(2, at=seq(0,3,1), labels=seq(0,3,1))
abline(v=c(0,1.96),lty=c(2,1),lwd=c(2,2))
abline(v=c(0,1.65),lty=c(2,1),lwd=c(2,2))
dev.off()
rm(h)

pdf("./output/figures_final/OESBIT_tstat_zoom.pdf",width=9,height=6)
x<-length(OESBIT$t[OESBIT$t>3])
y<-length(OESBIT$t[OESBIT$t<0])
notes<-paste(x,"arms with t>3 and",y,"arms with t<0 not shown")
h <- hist(OESBIT$t[OESBIT$t<=3 & OESBIT$t>=0],
          col="light blue",
          breaks=c(0,0.15,0.3,0.45,0.6,0.75,0.9,
                   1.05,1.2,1.35,1.5,1.65,1.805,1.96,
                   2.1,2.25,2.4,2.55,2.7,2.85,3),
          axes=F,
          xlab="All t-stats",
          cex.lab=1.5,
          ylim=c(0,13.5),
          main="Nudge Units",
          freq=TRUE
)
adj.old <- par()$adj
par(adj=0)
title(sub=notes)
par(adj = adj.old)
text(h$mids,h$counts,labels=h$counts, adj=c(0.5, -0.5))
axis(1, at=c(0,0.6,1.2,1.65,1.96,2.4,3), 
     labels=c("0","0.6","1.2","1.65","1.96","2.4","3"))
axis(2, at=seq(0,13,2), labels=seq(0,13,2))
abline(v=c(0,1.96),lty=c(2,1),lwd=c(2,2))
abline(v=c(0,1.65),lty=c(2,1),lwd=c(2,2))
dev.off()
rm(h)

pdf("./output/figures_final/OESBIT_tstat_MostSig_zoom.pdf",width=9,height=6)
x<-length(OESBITMS$t[OESBITMS$t>3])
y<-length(OESBITMS$t[OESBITMS$t<0])
notes<-paste(x,"trials with max-t>3 and",y,"trials with max-t<0 not shown")
h <- hist(OESBITMS$t[OESBITMS$t<=3 & OESBITMS$t>=0],
          col="light blue",
          breaks=c(0,0.15,0.3,0.45,0.6,0.75,0.9,
                   1.05,1.2,1.35,1.5,1.65,1.805,1.96,
                   2.1,2.25,2.4,2.55,2.7,2.85,3),
          axes=F,
          xlab="Max t-stat within each trial only",
          cex.lab=1.5,
          ylim=c(0,7.5),
          main="Nudge Units",
          freq=TRUE
)
adj.old <- par()$adj
par(adj=0)
title(sub=notes)
par(adj = adj.old)
text(h$mids,h$counts,labels=h$counts, adj=c(0.5, -0.5))
axis(1, at=c(0,0.6,1.2,1.65,1.96,2.4,3), 
     labels=c("0","0.6","1.2","1.65","1.96","2.4","3"))
axis(2, at=seq(0,7,1), labels=seq(0,7,1))
abline(v=c(0,1.96),lty=c(2,1),lwd=c(2,2))
abline(v=c(0,1.65),lty=c(2,1),lwd=c(2,2))
dev.off()
rm(h)




# Figures A6a-d
pdf("./output/figures_final/Brodeur_tstat_zoom.pdf",width=9,height=6)
x<-length(Brodeur$t[Brodeur$t>3])
notes<-paste(x,"test statistics with t>3 not shown")
h <- hist(Brodeur$t[Brodeur$t<=3],
          col="light blue",
          breaks=c(0,0.15,0.3,0.45,0.6,0.75,0.9,
                   1.05,1.2,1.35,1.5,1.65,1.805,1.96,
                   2.1,2.25,2.4,2.55,2.7,2.85,3),
          axes=F,
          xlab="All t-stats within paper",
          cex.lab=1.5,
          ylim=c(0,350),
          main="All trials",
          freq=TRUE
)
adj.old <- par()$adj
par(adj=0)
title(sub=notes)
par(adj = adj.old)
axis(1, at=c(0,0.6,1.2,1.65,1.96,2.4,3), 
     labels=c("0","0.6","1.2","1.65","1.96","2.4","3"))
axis(2, at=seq(0,350,50), labels=seq(0,350,50))
abline(v=c(0,1.96),lty=c(2,1),lwd=c(2,2))
abline(v=c(0,1.65),lty=c(2,1),lwd=c(2,2))
dev.off()
rm(h)

x<-length(BrodeurMaxt$t[BrodeurMaxt$t>3])
notes<-paste(x,"papers with max t-stat>3 not shown")
pdf("./output/figures_final/Brodeur_maxtstat_zoom.pdf",width=9,height=6)
h <- hist(BrodeurMaxt$t[BrodeurMaxt$t<=3],
          col="light blue",
          breaks=c(0,0.15,0.3,0.45,0.6,0.75,0.9,
                   1.05,1.2,1.35,1.5,1.65,1.805,1.96,
                   2.1,2.25,2.4,2.55,2.7,2.85,3),
          axes=F,
          xlab="Max t-stat within paper",
          cex.lab=1.5,
          ylim=c(0,30),
          main="All trials",
          freq=TRUE
)
adj.old <- par()$adj
par(adj=0)
title(sub=notes)
par(adj = adj.old)
text(h$mids,h$counts,labels=h$counts, adj=c(0.5, -0.5))
axis(1, at=c(0,0.6,1.2,1.65,1.96,2.4,3), 
     labels=c("0","0.6","1.2","1.65","1.96","2.4","3"))
axis(2, at=seq(0,30,10), labels=seq(0,30,10))
abline(v=c(0,1.96),lty=c(2,1),lwd=c(2,2))
abline(v=c(0,1.65),lty=c(2,1),lwd=c(2,2))
dev.off()
rm(h)

pdf("./output/figures_final/Brodeur_RCT_tstat_zoom.pdf",width=9,height=6)
x<-length(Brodeur$t[Brodeur$method=="RCT" & Brodeur$t>3])
notes<-paste(x,"test statistics with t>3 not shown")
h <- hist(Brodeur$t[Brodeur$method=="RCT" & Brodeur$t<=3],
          col="light blue",
          breaks=c(0,0.15,0.3,0.45,0.6,0.75,0.9,
                   1.05,1.2,1.35,1.5,1.65,1.805,1.96,
                   2.1,2.25,2.4,2.55,2.7,2.85,3),
          axes=F,
          xlab="All t-stats within paper",
          cex.lab=1.5,
          ylim=c(0,120),
          main="RCT",
          freq=TRUE
)
adj.old <- par()$adj
par(adj=0)
title(sub=notes)
par(adj = adj.old)
axis(1, at=c(0,0.6,1.2,1.65,1.96,2.4,3), 
     labels=c("0","0.6","1.2","1.65","1.96","2.4","3"))
axis(2, at=seq(0,120,20), labels=seq(0,120,20))
abline(v=c(0,1.96),lty=c(2,1),lwd=c(2,2))
abline(v=c(0,1.65),lty=c(2,1),lwd=c(2,2))
dev.off()
rm(h)

pdf("./output/figures_final/Brodeur_RCT_maxtstat_zoom.pdf",width=9,height=6)
x<-length(BrodeurMaxt$t[BrodeurMaxt$method=="RCT" & BrodeurMaxt$t>3])
notes<-paste(x,"papers with max t-stat>3 not shown")
h <- hist(BrodeurMaxt$t[BrodeurMaxt$method=="RCT" & BrodeurMaxt$t<=3],
          col="light blue",
          breaks=c(0,0.15,0.3,0.45,0.6,0.75,0.9,
                   1.05,1.2,1.35,1.5,1.65,1.805,1.96,
                   2.1,2.25,2.4,2.55,2.7,2.85,3),
          axes=F,
          xlab="Max t-stat within paper",
          cex.lab=1.5,
          ylim=c(0,6.5),
          main="RCT",
          freq=TRUE
)
adj.old <- par()$adj
par(adj=0)
title(sub=notes)
par(adj = adj.old)
text(h$mids,h$counts,labels=h$counts, adj=c(0.5, -0.5))
axis(1, at=c(0,0.6,1.2,1.65,1.96,2.4,3), 
     labels=c("0","0.6","1.2","1.65","1.96","2.4","3"))
axis(2, at=seq(0,6,1), labels=seq(0,6,1))
abline(v=c(0,1.96),lty=c(2,1),lwd=c(2,2))
abline(v=c(0,1.65),lty=c(2,1),lwd=c(2,2))
dev.off()
rm(h)





# Figures A9b,c
pdf("./output/figures_final/OESBIT_tstat_published.pdf",width=9,height=6)
hist(OESBIT$t[OESBIT$publication==1],
     col="light blue",
     breaks=c(-4.46,-3.96,-3.46,-2.96,-2.46,-1.96,-1.46,-0.96,-0.48,0,0.48,0.96,1.46,1.96,2.46,2.96,3.46,3.96,4.46,4.96,5.46,5.96,6.46),
     axes=F,
     xlab="t=Effect size/Standard error",
     cex.lab=1.5,
     main="",
     freq=TRUE
)
axis(1, at=c(-4.21,-2.96,-1.96,-0.96,0,0.96,1.96,2.96,3.96,4.96,6.21),
     labels=c("<-3.96","-2.96","-1.96","-0.96","0","0.96","1.96","2.96","3.96","4.96",">5.96"))
axis(2)
abline(v=c(-1.96,0,1.96),lty=c(1,2,1),lwd=c(2,2,2))
dev.off()

pdf("./output/figures_final/OESBIT_tstat_MostSig_published.pdf",width=9,height=6)
hist(OESBITMS$t[OESBITMS$publication==1],
     col="light blue",
     breaks=c(-4.46,-3.96,-3.46,-2.96,-2.46,-1.96,-1.46,-0.96,-0.48,0,0.48,0.96,1.46,1.96,2.46,2.96,3.46,3.96,4.46,4.96,5.46,5.96,6.46),
     axes=F,
     xlab="t=Effect size/Standard error",
     cex.lab=1.5,
     main="",
     freq=TRUE
)
axis(1, at=c(-4.21,-2.96,-1.96,-0.96,0,0.96,1.96,2.96,3.96,4.96,6.21),
     labels=c("<-3.96","-2.96","-1.96","-0.96","0","0.96","1.96","2.96","3.96","4.96",">5.96"))
axis(2, at=seq(0,3,1), labels=seq(0,3,1))
abline(v=c(-1.96,0,1.96),lty=c(1,2,1),lwd=c(2,2,2))
dev.off()